/*
 * Copyright 2004,2006 Jacek Caban for CodeWeavers
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef __MSHTMDID_H__
#define __MSHTMDID_H__

#define DISPID_NORMAL_FIRST     1000
#define DISPID_OMDOCUMENT       DISPID_NORMAL_FIRST
#define DISPID_ANCHOR           DISPID_NORMAL_FIRST
#define DISPID_BLOCK            DISPID_NORMAL_FIRST
#define DISPID_BR               DISPID_NORMAL_FIRST
#define DISPID_BGSOUND          DISPID_NORMAL_FIRST
#define DISPID_DD               DISPID_NORMAL_FIRST
#define DISPID_DIR              DISPID_NORMAL_FIRST
#define DISPID_DIV              DISPID_NORMAL_FIRST
#define DISPID_DL               DISPID_NORMAL_FIRST
#define DISPID_DT               DISPID_NORMAL_FIRST
#define DISPID_EFONT            DISPID_NORMAL_FIRST
#define DISPID_FORM             DISPID_NORMAL_FIRST
#define DISPID_HEADER           DISPID_NORMAL_FIRST
#define DISPID_HEDELEMS         DISPID_NORMAL_FIRST
#define DISPID_HR               DISPID_NORMAL_FIRST
#define DISPID_LABEL            DISPID_NORMAL_FIRST
#define DISPID_LI               DISPID_NORMAL_FIRST
#define DISPID_IMGBASE          DISPID_NORMAL_FIRST
#define DISPID_MENU             DISPID_NORMAL_FIRST
#define DISPID_OL               DISPID_NORMAL_FIRST
#define DISPID_PARA             DISPID_NORMAL_FIRST
#define DISPID_SELECT           DISPID_NORMAL_FIRST
#define DISPID_SELECTOBJ        DISPID_NORMAL_FIRST
#define DISPID_TABLE            DISPID_NORMAL_FIRST
#define DISPID_TEXTSITE         DISPID_NORMAL_FIRST
#define DISPID_UL               DISPID_NORMAL_FIRST
#define DISPID_PHRASE           DISPID_NORMAL_FIRST
#define DISPID_UNKNOWNPDL       DISPID_NORMAL_FIRST
#define DISPID_COMMENTPDL       DISPID_NORMAL_FIRST
#define DISPID_RANGE            DISPID_NORMAL_FIRST
#define DISPID_SELECTION        DISPID_NORMAL_FIRST
#define DISPID_OPTION           DISPID_NORMAL_FIRST
#define DISPID_RANGE            DISPID_NORMAL_FIRST
#define DISPID_SELECTION        DISPID_NORMAL_FIRST
#define DISPID_OPTION           DISPID_NORMAL_FIRST
#define DISPID_RANGE            DISPID_NORMAL_FIRST
#define DISPID_SELECTION        DISPID_NORMAL_FIRST
#define DISPID_OPTION           DISPID_NORMAL_FIRST
#define DISPID_RANGE            DISPID_NORMAL_FIRST
#define DISPID_SELECTION        DISPID_NORMAL_FIRST
#define DISPID_OPTION           DISPID_NORMAL_FIRST
#define DISPID_RANGE            DISPID_NORMAL_FIRST
#define DISPID_SELECTION        DISPID_NORMAL_FIRST
#define DISPID_OPTION           DISPID_NORMAL_FIRST
#define DISPID_MAP              DISPID_NORMAL_FIRST
#define DISPID_AREA             DISPID_NORMAL_FIRST
#define DISPID_PARAM            DISPID_NORMAL_FIRST
#define DISPID_TABLESECTION     DISPID_NORMAL_FIRST
#define DISPID_TABLEROW         DISPID_NORMAL_FIRST
#define DISPID_TABLECOL         DISPID_NORMAL_FIRST
#define DISPID_SCRIPT           DISPID_NORMAL_FIRST
#define DISPID_STYLESHEET       DISPID_NORMAL_FIRST
#define DISPID_STYLERULE        DISPID_NORMAL_FIRST
#define DISPID_STYLESHEETS_COL  DISPID_NORMAL_FIRST
#define DISPID_STYLERULES_COL   DISPID_NORMAL_FIRST
#define DISPID_MIMETYPES_COL    DISPID_NORMAL_FIRST
#define DISPID_PLUGINS_COL      DISPID_NORMAL_FIRST
#define DISPID_2D               DISPID_NORMAL_FIRST
#define DISPID_OMWINDOW         DISPID_NORMAL_FIRST
#define DISPID_EVENTOBJ         DISPID_NORMAL_FIRST
#define DISPID_OLESITE          DISPID_NORMAL_FIRST
#define DISPID_FRAMESET         DISPID_NORMAL_FIRST
#define DISPID_LINK             DISPID_NORMAL_FIRST
#define DISPID_STYLEELEMENT     DISPID_NORMAL_FIRST
#define DISPID_FILTERS          DISPID_NORMAL_FIRST
#define DISPID_TABLESECTION     DISPID_NORMAL_FIRST
#define DISPID_OMRECT           DISPID_NORMAL_FIRST
#define DISPID_OMDOCUMENT       DISPID_NORMAL_FIRST
#define DISPID_SCREEN           DISPID_NORMAL_FIRST
#define DISPID_DOMATTRIBUTE     DISPID_NORMAL_FIRST
#define DISPID_DOMIMPLEMENTATION  DISPID_NORMAL_FIRST

#define DISPID_COLLECTION      (DISPID_NORMAL_FIRST+500)
#define DISPID_IMG             (DISPID_IMGBASE+1000)
#define DISPID_INPUTIMAGE      (DISPID_IMGBASE+1000)
#define DISPID_INPUT           (DISPID_TEXTSITE+1000)
#define DISPID_TABLECELL       (DISPID_TEXTSITE+1000)
#define DISPID_1D              (DISPID_TEXTSITE+1000)
#define DISPID_BODY            (DISPID_TEXTSITE+1000)
#define DISPID_INPUTTEXTBASE   (DISPID_INPUT+1000)
#define DISPID_INPUTTEXT       (DISPID_INPUTTEXTBASE+1000)
#define DISPID_TEXTAREA        (DISPID_INPUTTEXT+1000)
#define DISPID_MARQUEE         (DISPID_TEXTAREA+1000)
#define DISPID_RICHTEXT        (DISPID_MARQUEE+1000)
#define DISPID_BUTTON          (DISPID_RICHTEXT+1000)

#define DISPID_XOBJ_MIN       0x80010000
#define DISPID_XOBJ_MAX       0x8001FFFF
#define DISPID_XOBJ_BASE      DISPID_XOBJ_MIN
#define DISPID_HTMLOBJECT     (DISPID_XOBJ_BASE+500)
#define DISPID_ELEMENT        (DISPID_HTMLOBJECT+500)
#define DISPID_SITE           (DISPID_ELEMENT+1000)
#define DISPID_OBJECT         (DISPID_SITE+1000)
#define DISPID_STYLE          (DISPID_OBJECT+1000)
#define DISPID_ATTRS          (DISPID_STYLE+1000)
#define DISPID_EVENTS         (DISPID_ATTRS+1000)
#define DISPID_XOBJ_EXPANDO   (DISPID_EVENTS+1000)
#define DISPID_XOBJ_ORDINAL   (DISPID_XOBJ_EXPANDO+1000)
#define DISPID_RADIO          (DISPID_CHECKBOX+1000)
#define DISPID_FRAMESITE      (DISPID_SITE+1000)
#define DISPID_FRAME          (DISPID_FRAMESITE+1000)
#define DISPID_IFRAME         (DISPID_FRAMESITE+1000)

#define DISPID_WINDOW      1
#define DISPID_HISTORY     1
#define DISPID_LOCATION    1
#define DISPID_NAVIGATOR   1

#define STDPROPID_XOBJ_NAME              (DISPID_XOBJ_BASE+0)
#define STDPROPID_XOBJ_INDEX             (DISPID_XOBJ_BASE+1)
#define STDPROPID_XOBJ_BASEHREF          (DISPID_XOBJ_BASE+2)
#define STDPROPID_XOBJ_LEFT              (DISPID_XOBJ_BASE+3)
#define STDPROPID_XOBJ_TOP               (DISPID_XOBJ_BASE+4)
#define STDPROPID_XOBJ_WIDTH             (DISPID_XOBJ_BASE+5)
#define STDPROPID_XOBJ_HEIGHT            (DISPID_XOBJ_BASE+6)
#define STDPROPID_XOBJ_VISIBLE           (DISPID_XOBJ_BASE+7)
#define STDPROPID_XOBJ_PARENT            (DISPID_XOBJ_BASE+8)
#define STDPROPID_XOBJ_DRAGMODE          (DISPID_XOBJ_BASE+9)
#define STDPROPID_XOBJ_DRAGICON          (DISPID_XOBJ_BASE+10)
#define STDPROPID_XOBJ_TAG               (DISPID_XOBJ_BASE+11)
#define STDPROPID_XOBJ_TABSTOP           (DISPID_XOBJ_BASE+14)
#define STDPROPID_XOBJ_TABINDEX          (DISPID_XOBJ_BASE+15)
#define STDPROPID_XOBJ_HELPCONTEXTID     (DISPID_XOBJ_BASE+50)
#define STDPROPID_XOBJ_DEFAULT           (DISPID_XOBJ_BASE+55)
#define STDPROPID_XOBJ_CANCEL            (DISPID_XOBJ_BASE+56)
#define STDPROPID_XOBJ_LEFTNORUN         (DISPID_XOBJ_BASE+57)
#define STDPROPID_XOBJ_TOPNORUN          (DISPID_XOBJ_BASE+58)
#define STDPROPID_XOBJ_ALIGNPERSIST      (DISPID_XOBJ_BASE+60)
#define STDPROPID_XOBJ_LINKTIMEOUT       (DISPID_XOBJ_BASE+61)
#define STDPROPID_XOBJ_LINKTOPIC         (DISPID_XOBJ_BASE+62)
#define STDPROPID_XOBJ_LINKITEM          (DISPID_XOBJ_BASE+63)
#define STDPROPID_XOBJ_LINKMODE          (DISPID_XOBJ_BASE+64)
#define STDPROPID_XOBJ_DATACHANGED       (DISPID_XOBJ_BASE+65)
#define STDPROPID_XOBJ_DATAFIELD         (DISPID_XOBJ_BASE+66)
#define STDPROPID_XOBJ_DATASOURCE        (DISPID_XOBJ_BASE+67)
#define STDPROPID_XOBJ_WHATSTHISHELPID   (DISPID_XOBJ_BASE+68)
#define STDPROPID_XOBJ_CONTROLTIPTEXT    (DISPID_XOBJ_BASE+69)
#define STDPROPID_XOBJ_STATUSBARTEXT     (DISPID_XOBJ_BASE+70)
#define STDPROPID_XOBJ_APPLICATION       (DISPID_XOBJ_BASE+71)
#define STDPROPID_XOBJ_BLOCKALIGN        (DISPID_XOBJ_BASE+72)
#define STDPROPID_XOBJ_CONTROLALIGN      (DISPID_XOBJ_BASE+73)
#define STDPROPID_XOBJ_STYLE             (DISPID_XOBJ_BASE+74)
#define STDPROPID_XOBJ_COUNT             (DISPID_XOBJ_BASE+75)
#define STDPROPID_XOBJ_DISABLED          (DISPID_XOBJ_BASE+76)
#define STDPROPID_XOBJ_RIGHT             (DISPID_XOBJ_BASE+77)
#define STDPROPID_XOBJ_BOTTOM            (DISPID_XOBJ_BASE+78)

#define STDDISPID_XOBJ_ONBLUR             (DISPID_XOBJ_BASE+0)
#define STDDISPID_XOBJ_ONFOCUS            (DISPID_XOBJ_BASE+1)
#define STDDISPID_XOBJ_BEFOREUPDATE       (DISPID_XOBJ_BASE+4)
#define STDDISPID_XOBJ_AFTERUPDATE        (DISPID_XOBJ_BASE+5)
#define STDDISPID_XOBJ_ONROWEXIT          (DISPID_XOBJ_BASE+6)
#define STDDISPID_XOBJ_ONROWENTER         (DISPID_XOBJ_BASE+7)
#define STDDISPID_XOBJ_ONMOUSEOVER        (DISPID_XOBJ_BASE+8)
#define STDDISPID_XOBJ_ONMOUSEOUT         (DISPID_XOBJ_BASE+9)
#define STDDISPID_XOBJ_ONHELP             (DISPID_XOBJ_BASE+10)
#define STDDISPID_XOBJ_ONDRAGSTART        (DISPID_XOBJ_BASE+11)
#define STDDISPID_XOBJ_ONSELECTSTART      (DISPID_XOBJ_BASE+12)
#define STDDISPID_XOBJ_ERRORUPDATE        (DISPID_XOBJ_BASE+13)
#define STDDISPID_XOBJ_ONDATASETCHANGED   (DISPID_XOBJ_BASE+14)
#define STDDISPID_XOBJ_ONDATAAVAILABLE    (DISPID_XOBJ_BASE+15)
#define STDDISPID_XOBJ_ONDATASETCOMPLETE  (DISPID_XOBJ_BASE+16)
#define STDDISPID_XOBJ_ONFILTER           (DISPID_XOBJ_BASE+17)
#define STDDISPID_XOBJ_ONLOSECAPTURE      (DISPID_XOBJ_BASE+18)
#define STDDISPID_XOBJ_ONPROPERTYCHANGE   (DISPID_XOBJ_BASE+19)
#define STDDISPID_XOBJ_ONDRAG             (DISPID_XOBJ_BASE+20)
#define STDDISPID_XOBJ_ONDRAGEND          (DISPID_XOBJ_BASE+21)
#define STDDISPID_XOBJ_ONDRAGENTER        (DISPID_XOBJ_BASE+22)
#define STDDISPID_XOBJ_ONDRAGOVER         (DISPID_XOBJ_BASE+23)
#define STDDISPID_XOBJ_ONDRAGLEAVE        (DISPID_XOBJ_BASE+24)
#define STDDISPID_XOBJ_ONDROP             (DISPID_XOBJ_BASE+25)
#define STDDISPID_XOBJ_ONCUT              (DISPID_XOBJ_BASE+26)
#define STDDISPID_XOBJ_ONCOPY             (DISPID_XOBJ_BASE+27)
#define STDDISPID_XOBJ_ONPASTE            (DISPID_XOBJ_BASE+28)
#define STDDISPID_XOBJ_ONBEFORECUT        (DISPID_XOBJ_BASE+29)
#define STDDISPID_XOBJ_ONBEFORECOPY       (DISPID_XOBJ_BASE+30)
#define STDDISPID_XOBJ_ONBEFOREPASTE      (DISPID_XOBJ_BASE+31)
#define STDDISPID_XOBJ_ONROWSDELETE       (DISPID_XOBJ_BASE+32)
#define STDDISPID_XOBJ_ONROWSINSERTED     (DISPID_XOBJ_BASE+33)
#define STDDISPID_XOBJ_ONCELLCHANGE       (DISPID_XOBJ_BASE+34)

#define DISPID_A_FIRST                       DISPID_ATTRS
#define DISPID_A_BACKGROUNDIMAGE             (DISPID_A_FIRST+1)
#define DISPID_A_COLOR                       (DISPID_A_FIRST+2)
#define DISPID_A_TEXTTRANSFORM               (DISPID_A_FIRST+4)
#define DISPID_A_NOWRAP                      (DISPID_A_FIRST+5)
#define DISPID_A_LINEHEIGHT                  (DISPID_A_FIRST+6)
#define DISPID_A_TEXTINDENT                  (DISPID_A_FIRST+7)
#define DISPID_A_LETTERSPACING               (DISPID_A_FIRST+8)
#define DISPID_A_LANG                        (DISPID_A_FIRST+9)
#define DISPID_A_OVERFLOW                    (DISPID_A_FIRST+10)
#define DISPID_A_PADDING                     (DISPID_A_FIRST+11)
#define DISPID_A_PADDINGTOP                  (DISPID_A_FIRST+12)
#define DISPID_A_PADDINGRIGHT                (DISPID_A_FIRST+13)
#define DISPID_A_PADDINGBOTTOM               (DISPID_A_FIRST+14)
#define DISPID_A_PADDINGLEFT                 (DISPID_A_FIRST+15)
#define DISPID_A_CLEAR                       (DISPID_A_FIRST+16)
#define DISPID_A_LISTTYPE                    (DISPID_A_FIRST+17)
#define DISPID_A_FONTFACE                    (DISPID_A_FIRST+18)
#define DISPID_A_FONTSIZE                    (DISPID_A_FIRST+19)
#define DISPID_A_TEXTDECORATIONLINETHROUGH   (DISPID_A_FIRST+20)
#define DISPID_A_TEXTDECORATIONUNDERLINE     (DISPID_A_FIRST+21)
#define DISPID_A_TEXTDECORATIONBLINK         (DISPID_A_FIRST+22)
#define DISPID_A_TEXTDECORATIONNONE          (DISPID_A_FIRST+23)
#define DISPID_A_FONTSTYLE                   (DISPID_A_FIRST+24)
#define DISPID_A_FONTVARIANT                 (DISPID_A_FIRST+25)
#define DISPID_A_BASEFONT                    (DISPID_A_FIRST+26)
#define DISPID_A_FONTWEIGHT                  (DISPID_A_FIRST+27)
#define DISPID_A_TABLEBORDERCOLOR            (DISPID_A_FIRST+28)
#define DISPID_A_TABLEBORDERCOLORLIGHT       (DISPID_A_FIRST+29)
#define DISPID_A_TABLEBORDERCOLORDARK        (DISPID_A_FIRST+30)
#define DISPID_A_TABLEVALIGN                 (DISPID_A_FIRST+31)
#define DISPID_A_BACKGROUND                  (DISPID_A_FIRST+32)
#define DISPID_A_BACKGROUNDPOSX              (DISPID_A_FIRST+33)
#define DISPID_A_BACKGROUNDPOSY              (DISPID_A_FIRST+34)
#define DISPID_A_TEXTDECORATION              (DISPID_A_FIRST+35)
#define DISPID_A_MARGIN                      (DISPID_A_FIRST+36)
#define DISPID_A_MARGINTOP                   (DISPID_A_FIRST+37)
#define DISPID_A_MARGINRIGHT                 (DISPID_A_FIRST+38)
#define DISPID_A_MARGINBOTTOM                (DISPID_A_FIRST+39)
#define DISPID_A_MARGINLEFT                  (DISPID_A_FIRST+40)
#define DISPID_A_FONT                        (DISPID_A_FIRST+41)
#define DISPID_A_FONTSIZEKEYWORD             (DISPID_A_FIRST+42)
#define DISPID_A_FONTSIZECOMBINE             (DISPID_A_FIRST+43)
#define DISPID_A_BACKGROUNDREPEAT            (DISPID_A_FIRST+44)
#define DISPID_A_BACKGROUNDATTACHMENT        (DISPID_A_FIRST+45)
#define DISPID_A_BACKGROUNDPOSITION          (DISPID_A_FIRST+46)
#define DISPID_A_WORDSPACING                 (DISPID_A_FIRST+47)
#define DISPID_A_VERTICALALIGN               (DISPID_A_FIRST+48)
#define DISPID_A_BORDER                      (DISPID_A_FIRST+49)
#define DISPID_A_BORDERTOP                   (DISPID_A_FIRST+50)
#define DISPID_A_BORDERRIGHT                 (DISPID_A_FIRST+51)
#define DISPID_A_BORDERBOTTOM                (DISPID_A_FIRST+52)
#define DISPID_A_BORDERLEFT                  (DISPID_A_FIRST+53)
#define DISPID_A_BORDERCOLOR                 (DISPID_A_FIRST+54)
#define DISPID_A_BORDERTOPCOLOR              (DISPID_A_FIRST+55)
#define DISPID_A_BORDERRIGHTCOLOR            (DISPID_A_FIRST+56)
#define DISPID_A_BORDERBOTTOMCOLOR           (DISPID_A_FIRST+57)
#define DISPID_A_BORDERLEFTCOLOR             (DISPID_A_FIRST+58)
#define DISPID_A_BORDERWIDTH                 (DISPID_A_FIRST+59)
#define DISPID_A_BORDERTOPWIDTH              (DISPID_A_FIRST+60)
#define DISPID_A_BORDERRIGHTWIDTH            (DISPID_A_FIRST+61)
#define DISPID_A_BORDERBOTTOMWIDTH           (DISPID_A_FIRST+62)
#define DISPID_A_BORDERLEFTWIDTH             (DISPID_A_FIRST+63)
#define DISPID_A_BORDERSTYLE                 (DISPID_A_FIRST+64)
#define DISPID_A_BORDERTOPSTYLE              (DISPID_A_FIRST+65)
#define DISPID_A_BORDERRIGHTSTYLE            (DISPID_A_FIRST+66)
#define DISPID_A_BORDERBOTTOMSTYLE           (DISPID_A_FIRST+67)
#define DISPID_A_BORDERLEFTSTYLE             (DISPID_A_FIRST+68)
#define DISPID_A_TEXTDECORATIONOVERLINE      (DISPID_A_FIRST+69)
#define DISPID_A_FLOAT                       (DISPID_A_FIRST+70)
#define DISPID_A_DISPLAY                     (DISPID_A_FIRST+71)
#define DISPID_A_LISTSTYLETYPE               (DISPID_A_FIRST+72)
#define DISPID_A_LISTSTYLEPOSITION           (DISPID_A_FIRST+73)
#define DISPID_A_LISTSTYLEIMAGE              (DISPID_A_FIRST+74)
#define DISPID_A_LISTSTYLE                   (DISPID_A_FIRST+75)
#define DISPID_A_WHITESPACE                  (DISPID_A_FIRST+76)
#define DISPID_A_PAGEBREAKBEFORE             (DISPID_A_FIRST+77)
#define DISPID_A_PAGEBREAKAFTER              (DISPID_A_FIRST+78)
#define DISPID_A_SCROLL                      (DISPID_A_FIRST+79)
#define DISPID_A_VISIBILITY                  (DISPID_A_FIRST+80)
#define DISPID_A_HIDDEN                      (DISPID_A_FIRST+81)
#define DISPID_A_FILTER                      (DISPID_A_FIRST+82)
#define DISPID_DEFAULTVALUE                  (DISPID_A_FIRST+83)
#define DISPID_A_BORDERCOLLAPSE              (DISPID_A_FIRST+84)
#define DISPID_A_POSITION                    (DISPID_A_FIRST+90)
#define DISPID_A_ZINDEX                      (DISPID_A_FIRST+91)
#define DISPID_A_CLIP                        (DISPID_A_FIRST+92)
#define DISPID_A_CLIPRECTTOP                 (DISPID_A_FIRST+93)
#define DISPID_A_CLIPRECTRIGHT               (DISPID_A_FIRST+94)
#define DISPID_A_CLIPRECTBOTTOM              (DISPID_A_FIRST+95)
#define DISPID_A_CLIPRECTLEFT                (DISPID_A_FIRST+96)
#define DISPID_A_FONTFACESRC                 (DISPID_A_FIRST+97)
#define DISPID_A_TABLELAYOUT                 (DISPID_A_FIRST+98)
#define DISPID_A_STYLETEXT                   (DISPID_A_FIRST+99)
#define DISPID_A_LANGUAGE                    (DISPID_A_FIRST+100)
#define DISPID_A_VALUE                       (DISPID_A_FIRST+101)
#define DISPID_A_CURSOR                      (DISPID_A_FIRST+102)
#define DISPID_A_EVENTSINK                   (DISPID_A_FIRST+103)
#define DISPID_A_PROPNOTIFYSINK              (DISPID_A_FIRST+104)
#define DISPID_A_ROWSETNOTIFYSINK            (DISPID_A_FIRST+105)
#define DISPID_INTERNAL_INLINESTYLEAA        (DISPID_A_FIRST+106)
#define DISPID_INTERNAL_CSTYLEPTRCACHE       (DISPID_A_FIRST+107)
#define DISPID_INTERNAL_CRUNTIMESTYLEPTRCACHE  (DISPID_A_FIRST+108)
#define DISPID_INTERNAL_INVOKECONTEXT        (DISPID_A_FIRST+109)
#define DISPID_A_BGURLIMGCTXCACHEINDEX       (DISPID_A_FIRST+110)
#define DISPID_A_LIURLIMGCTXCACHEINDEX       (DISPID_A_FIRST+111)
#define DISPID_A_ROWSETASYNCHNOTIFYSINK      (DISPID_A_FIRST+112)
#define DISPID_INTERNAL_FILTERPTRCACHE       (DISPID_A_FIRST+113)
#define DISPID_A_ROWPOSITIONCHANGESINK       (DISPID_A_FIRST+114)
#define DISPID_A_BEHAVIOR                    (DISPID_A_FIRST+115)
#define DISPID_A_READYSTATE                  (DISPID_A_FIRST+116)
#define DISPID_A_DIR                         (DISPID_A_FIRST+117)
#define DISPID_A_UNICODEBIDI                 (DISPID_A_FIRST+118)
#define DISPID_A_DIRECTION                   (DISPID_A_FIRST+119)
#define DISPID_A_IMEMODE                     (DISPID_A_FIRST+120) 
#define DISPID_A_RUBYALIGN                   (DISPID_A_FIRST+121)
#define DISPID_A_RUBYPOSITION                (DISPID_A_FIRST+122)
#define DISPID_A_RUBYOVERHANG                (DISPID_A_FIRST+123)
#define DISPID_INTERNAL_ONBEHAVIOR_CONTENTREADY   (DISPID_A_FIRST+124)
#define DISPID_INTERNAL_ONBEHAVIOR_DOCUMENTREADY  (DISPID_A_FIRST+125)
#define DISPID_INTERNAL_CDOMCHILDRENPTRCACHE (DISPID_A_FIRST+126)
#define DISPID_A_LAYOUTGRIDCHAR              (DISPID_A_FIRST+127)
#define DISPID_A_LAYOUTGRIDLINE              (DISPID_A_FIRST+128)
#define DISPID_A_LAYOUTGRIDMODE              (DISPID_A_FIRST+129)
#define DISPID_A_LAYOUTGRIDTYPE              (DISPID_A_FIRST+130)
#define DISPID_A_LAYOUTGRID                  (DISPID_A_FIRST+131)
#define DISPID_A_TEXTAUTOSPACE               (DISPID_A_FIRST+132)
#define DISPID_A_LINEBREAK                   (DISPID_A_FIRST+133)
#define DISPID_A_WORDBREAK                   (DISPID_A_FIRST+134)
#define DISPID_A_TEXTJUSTIFY                 (DISPID_A_FIRST+135)
#define DISPID_A_TEXTJUSTIFYTRIM             (DISPID_A_FIRST+136)
#define DISPID_A_TEXTKASHIDA                 (DISPID_A_FIRST+137)
#define DISPID_A_OVERFLOWX                   (DISPID_A_FIRST+139)
#define DISPID_A_OVERFLOWY                   (DISPID_A_FIRST+140)
#define DISPID_A_HTCDISPATCHITEM_VALUE       (DISPID_A_FIRST+141)
#define DISPID_A_DOCFRAGMENT                 (DISPID_A_FIRST+142)
#define DISPID_A_HTCDD_ELEMENT               (DISPID_A_FIRST+143)
#define DISPID_A_HTCDD_CREATEEVENTOBJECT     (DISPID_A_FIRST+144)
#define DISPID_A_URNATOM                     (DISPID_A_FIRST+145)
#define DISPID_A_UNIQUEPEERNUMBER            (DISPID_A_FIRST+146)
#define DISPID_A_ACCELERATOR                 (DISPID_A_FIRST+147)
#define DISPID_INTERNAL_ONBEHAVIOR_APPLYSTYLE       (DISPID_A_FIRST+148)
#define DISPID_INTERNAL_RUNTIMESTYLEAA              (DISPID_A_FIRST+149)
#define DISPID_A_HTCDISPATCHITEM_VALUE_SCRIPTSONLY  (DISPID_A_FIRST+150)
#define DISPID_A_EXTENDEDTAGDESC             (DISPID_A_FIRST+151)
#define DISPID_A_ROTATE                      (DISPID_A_FIRST+152)
#define DISPID_A_ZOOM                        (DISPID_A_FIRST+153)
#define DISPID_A_HTCDD_PROTECTEDELEMENT      (DISPID_A_FIRST+154)
#define DISPID_A_LAYOUTFLOW                  (DISPID_A_FIRST+155)
#define DISPID_A_HTCDD_ISMARKUPSHARED        (DISPID_A_FIRST+157)
#define DISPID_A_WORDWRAP                    (DISPID_A_FIRST+158)
#define DISPID_A_TEXTUNDERLINEPOSITION       (DISPID_A_FIRST+159)
#define DISPID_A_HASLAYOUT                   (DISPID_A_FIRST+160)
#define DISPID_A_MEDIA                       (DISPID_A_FIRST+161)
#define DISPID_A_EDITABLE                    (DISPID_A_FIRST+162)
#define DISPID_A_HIDEFOCUS                   (DISPID_A_FIRST+163)
#define DISPID_INTERNAL_LAYOUTRECTREGISTRYPTRCACHE  (DISPID_A_FIRST+164)
#define DISPID_A_HTCDD_DEFAULTS              (DISPID_A_FIRST+165)
#define DISPID_A_TEXTLINETHROUGHSTYLE        (DISPID_A_FIRST+166)
#define DISPID_A_TEXTUNDERLINESTYLE          (DISPID_A_FIRST+167)
#define DISPID_A_TEXTEFFECT                  (DISPID_A_FIRST+168)
#define DISPID_A_TEXTBACKGROUNDCOLOR         (DISPID_A_FIRST+169)
#define DISPID_A_RENDERINGPRIORITY           (DISPID_A_FIRST+170)
#define DISPID_INTERNAL_DWNPOSTPTRCACHE      (DISPID_A_FIRST+171)
#define DISPID_INTERNAL_CODEPAGESETTINGSPTRCACHE  (DISPID_A_FIRST+172)
#define DISPID_INTERNAL_DWNDOCPTRCACHE       (DISPID_A_FIRST+173)
#define DISPID_INTERNAL_DATABINDTASKPTRCACHE (DISPID_A_FIRST+174)
#define DISPID_INTERNAL_URLLOCATIONCACHE     (DISPID_A_FIRST+175)
#define DISPID_INTERNAL_ARYELEMENTRELEASENOTIFYPTRCACHE  (DISPID_A_FIRST+176)
#define DISPID_INTERNAL_PEERFACTORYURLMAPPTRCACHE        (DISPID_A_FIRST+177)
#define DISPID_INTERNAL_STMDIRTYPTRCACHE     (DISPID_A_FIRST+178)
#define DISPID_INTERNAL_COMPUTEFORMATSTATECACHE  (DISPID_A_FIRST+179)
#define DISPID_A_SCROLLBARBASECOLOR          (DISPID_A_FIRST+180)
#define DISPID_A_SCROLLBARFACECOLOR          (DISPID_A_FIRST+181)
#define DISPID_A_SCROLLBAR3DLIGHTCOLOR       (DISPID_A_FIRST+182)
#define DISPID_A_SCROLLBARSHADOWCOLOR        (DISPID_A_FIRST+183)
#define DISPID_A_SCROLLBARHIGHLIGHTCOLOR     (DISPID_A_FIRST+184)
#define DISPID_A_SCROLLBARDARKSHADOWCOLOR    (DISPID_A_FIRST+185)
#define DISPID_A_SCROLLBARARROWCOLOR         (DISPID_A_FIRST+186)
#define DISPID_INTERNAL_ONBEHAVIOR_CONTENTSAVE  (DISPID_A_FIRST+187)
#define DISPID_A_DEFAULTTEXTSELECTION        (DISPID_A_FIRST+188)
#define DISPID_A_TEXTDECORATIONCOLOR         (DISPID_A_FIRST+189)
#define DISPID_A_TEXTCOLOR                   (DISPID_A_FIRST+190)
#define DISPID_A_STYLETEXTDECORATION         (DISPID_A_FIRST+191)
#define DISPID_A_WRITINGMODE                 (DISPID_A_FIRST+192)
#define DISPID_INTERNAL_MEDIA_REFERENCE      (DISPID_A_FIRST+193)
#define DISPID_INTERNAL_GENERICCOMPLUSREF    (DISPID_A_FIRST+194)
#define DISPID_INTERNAL_FOCUSITEMS           (DISPID_A_FIRST+195)
#define DISPID_A_SCROLLBARTRACKCOLOR         (DISPID_A_FIRST+196)
#define DISPID_INTERNAL_DWNHEADERCACHE       (DISPID_A_FIRST+197)
#define DISPID_A_FROZEN                      (DISPID_A_FIRST+198)
#define DISPID_A_VIEWINHERITSTYLE            (DISPID_A_FIRST+199)
#define DISPID_INTERNAL_FRAMESCOLLECTION     (DISPID_A_FIRST+200)
#define DISPID_A_BGURLIMGCTXCACHEINDEX_FLINE (DISPID_A_FIRST+201)
#define DISPID_A_BGURLIMGCTXCACHEINDEX_FLETTER  (DISPID_A_FIRST+202)
#define DISPID_A_TEXTALIGNLAST               (DISPID_A_FIRST+203)
#define DISPID_A_TEXTKASHIDASPACE            (DISPID_A_FIRST+204)
#define DISPID_INTERNAL_FONTHISTORYINDEX     (DISPID_A_FIRST+205)
#define DISPID_A_ALLOWTRANSPARENCY           (DISPID_A_FIRST+206)
#define DISPID_INTERNAL_URLSEARCHCACHE       (DISPID_A_FIRST+207)
#define DISPID_A_ISBLOCK                     (DISPID_A_FIRST+208)
#define DISPID_A_TEXTOVERFLOW                (DISPID_A_FIRST+209)
#define DISPID_INTERNAL_CATTRIBUTECOLLPTRCACHE  (DISPID_A_FIRST+210)
#define DISPID_A_MINHEIGHT                   (DISPID_A_FIRST+211)

#define DISPID_WINDOWOBJECT          (-5500)
#define DISPID_LOCATIONOBJECT        (-5506)
#define DISPID_HISTORYOBJECT         (-5507)
#define DISPID_NAVIGATOROBJECT       (-5508)
#define DISPID_SECURITYCTX           (-5511)
#define DISPID_AMBIENT_DLCONTROL     (-5512)
#define DISPID_AMBIENT_USERAGENT     (-5513)
#define DISPID_SECURITYDOMAIN        (-5514)

#define DLCTL_DLIMAGES               0x00000010
#define DLCTL_VIDEOS                 0x00000020
#define DLCTL_BGSOUNDS               0x00000040
#define DLCTL_NO_SCRIPTS             0x00000080
#define DLCTL_NO_JAVA                0x00000100
#define DLCTL_NO_RUNACTIVEXCTLS      0x00000200
#define DLCTL_NO_DLACTIVEXCTLS       0x00000400
#define DLCTL_DOWNLOADONLY           0x00000800
#define DLCTL_NO_FRAMEDOWNLOAD       0x00001000
#define DLCTL_RESYNCHRONIZE          0x00002000
#define DLCTL_PRAGMA_NO_CACHE        0x00004000
#define DLCTL_FORCEOFFLINE           0x10000000
#define DLCTL_NO_CLIENTPULL          0x20000000
#define DLCTL_SILENT                 0x40000000
#define DLCTL_OFFLINEIFNOTCONNECTED  0x80000000
#define DLCTL_OFFLINE                DLCTL_OFFLINEIFNOTCONNECTED

/* events */
#define DISPID_EVPROP_ONMOUSEOVER          (DISPID_EVENTS+0)
#define DISPID_EVPROP_ONMOUSEOUT           (DISPID_EVENTS+1)
#define DISPID_EVPROP_ONMOUSEDOWN          (DISPID_EVENTS+2)
#define DISPID_EVPROP_ONMOUSEUP            (DISPID_EVENTS+3)
#define DISPID_EVPROP_ONMOUSEMOVE          (DISPID_EVENTS+4)
#define DISPID_EVPROP_ONKEYDOWN            (DISPID_EVENTS+5)
#define DISPID_EVPROP_ONKEYUP              (DISPID_EVENTS+6)
#define DISPID_EVPROP_ONKEYPRESS           (DISPID_EVENTS+7)
#define DISPID_EVPROP_ONCLICK              (DISPID_EVENTS+8)
#define DISPID_EVPROP_ONDBLCLICK           (DISPID_EVENTS+9)
#define DISPID_EVPROP_ONSELECT             (DISPID_EVENTS+10)
#define DISPID_EVPROP_ONSUBMIT             (DISPID_EVENTS+11)
#define DISPID_EVPROP_ONRESET              (DISPID_EVENTS+12)
#define DISPID_EVPROP_ONHELP               (DISPID_EVENTS+13)
#define DISPID_EVPROP_ONFOCUS              (DISPID_EVENTS+14)
#define DISPID_EVPROP_ONBLUR               (DISPID_EVENTS+15)
#define DISPID_EVPROP_ONROWEXIT            (DISPID_EVENTS+18)
#define DISPID_EVPROP_ONROWENTER           (DISPID_EVENTS+19)
#define DISPID_EVPROP_ONBOUNCE             (DISPID_EVENTS+20)
#define DISPID_EVPROP_ONBEFOREUPDATE       (DISPID_EVENTS+21)
#define DISPID_EVPROP_ONAFTERUPDATE        (DISPID_EVENTS+22)
#define DISPID_EVPROP_ONBEFOREDRAGOVER     (DISPID_EVENTS+23)
#define DISPID_EVPROP_ONBEFOREDROPORPASTE  (DISPID_EVENTS+24)
#define DISPID_EVPROP_ONREADYSTATECHANGE   (DISPID_EVENTS+25)
#define DISPID_EVPROP_ONFINISH             (DISPID_EVENTS+26)
#define DISPID_EVPROP_ONSTART              (DISPID_EVENTS+27)
#define DISPID_EVPROP_ONABORT              (DISPID_EVENTS+28)
#define DISPID_EVPROP_ONERROR              (DISPID_EVENTS+29)
#define DISPID_EVPROP_ONCHANGE             (DISPID_EVENTS+30)
#define DISPID_EVPROP_ONSCROLL             (DISPID_EVENTS+31)
#define DISPID_EVPROP_ONLOAD               (DISPID_EVENTS+32)
#define DISPID_EVPROP_ONUNLOAD             (DISPID_EVENTS+33)
#define DISPID_EVPROP_ONLAYOUT             (DISPID_EVENTS+34)
#define DISPID_EVPROP_ONDRAGSTART          (DISPID_EVENTS+35)
#define DISPID_EVPROP_ONRESIZE             (DISPID_EVENTS+36)
#define DISPID_EVPROP_ONSELECTSTART        (DISPID_EVENTS+37)
#define DISPID_EVPROP_ONERRORUPDATE        (DISPID_EVENTS+38)
#define DISPID_EVPROP_ONBEFOREUNLOAD       (DISPID_EVENTS+39)
#define DISPID_EVPROP_ONDATASETCHANGED     (DISPID_EVENTS+40)
#define DISPID_EVPROP_ONDATAAVAILABLE      (DISPID_EVENTS+41)
#define DISPID_EVPROP_ONDATASETCOMPLETE    (DISPID_EVENTS+42)
#define DISPID_EVPROP_ONFILTER             (DISPID_EVENTS+43)
#define DISPID_EVPROP_ONCHANGEFOCUS        (DISPID_EVENTS+44)
#define DISPID_EVPROP_ONCHANGEBLUR         (DISPID_EVENTS+45)
#define DISPID_EVPROP_ONLOSECAPTURE        (DISPID_EVENTS+46)
#define DISPID_EVPROP_ONPROPERTYCHANGE     (DISPID_EVENTS+47)
#define DISPID_EVPROP_ONPERSISTSAVE        (DISPID_EVENTS+48)
#define DISPID_EVPROP_ONDRAG               (DISPID_EVENTS+49)
#define DISPID_EVPROP_ONDRAGEND            (DISPID_EVENTS+50)
#define DISPID_EVPROP_ONDRAGENTER          (DISPID_EVENTS+51)
#define DISPID_EVPROP_ONDRAGOVER           (DISPID_EVENTS+52)
#define DISPID_EVPROP_ONDRAGLEAVE          (DISPID_EVENTS+53)
#define DISPID_EVPROP_ONDROP               (DISPID_EVENTS+54)
#define DISPID_EVPROP_ONCUT                (DISPID_EVENTS+55)
#define DISPID_EVPROP_ONCOPY               (DISPID_EVENTS+56)
#define DISPID_EVPROP_ONPASTE              (DISPID_EVENTS+57)
#define DISPID_EVPROP_ONBEFORECUT          (DISPID_EVENTS+58)
#define DISPID_EVPROP_ONBEFORECOPY         (DISPID_EVENTS+59)
#define DISPID_EVPROP_ONBEFOREPASTE        (DISPID_EVENTS+60)
#define DISPID_EVPROP_ONPERSISTLOAD        (DISPID_EVENTS+61)
#define DISPID_EVPROP_ONROWSDELETE         (DISPID_EVENTS+62)
#define DISPID_EVPROP_ONROWSINSERTED       (DISPID_EVENTS+63)
#define DISPID_EVPROP_ONCELLCHANGE         (DISPID_EVENTS+64)
#define DISPID_EVPROP_ONCONTEXTMENU        (DISPID_EVENTS+65)
#define DISPID_EVPROP_ONBEFOREPRINT        (DISPID_EVENTS+66)
#define DISPID_EVPROP_ONAFTERPRINT         (DISPID_EVENTS+67)
#define DISPID_EVPROP_ONSTOP               (DISPID_EVENTS+68)
#define DISPID_EVPROP_ONBEFOREEDITFOCUS    (DISPID_EVENTS+69)
#define DISPID_EVPROP_ONATTACHEVENT        (DISPID_EVENTS+70)
#define DISPID_EVPROP_ONMOUSEHOVER         (DISPID_EVENTS+71)
#define DISPID_EVPROP_ONCONTENTREADY       (DISPID_EVENTS+72)
#define DISPID_EVPROP_ONLAYOUTCOMPLETE     (DISPID_EVENTS+73)
#define DISPID_EVPROP_ONPAGE               (DISPID_EVENTS+74)
#define DISPID_EVPROP_ONLINKEDOVERFLOW     (DISPID_EVENTS+75)
#define DISPID_EVPROP_ONMOUSEWHEEL         (DISPID_EVENTS+76)
#define DISPID_EVPROP_ONBEFOREDEACTIVATE   (DISPID_EVENTS+77)
#define DISPID_EVPROP_ONMOVE               (DISPID_EVENTS+78)
#define DISPID_EVPROP_ONCONTROLSELECT      (DISPID_EVENTS+79)
#define DISPID_EVPROP_ONSELECTIONCHANGE    (DISPID_EVENTS+80)
#define DISPID_EVPROP_ONMOVESTART          (DISPID_EVENTS+81)
#define DISPID_EVPROP_ONMOVEEND            (DISPID_EVENTS+82)
#define DISPID_EVPROP_ONRESIZESTART        (DISPID_EVENTS+83)
#define DISPID_EVPROP_ONRESIZEEND          (DISPID_EVENTS+84)
#define DISPID_EVPROP_ONMOUSEENTER         (DISPID_EVENTS+85)
#define DISPID_EVPROP_ONMOUSELEAVE         (DISPID_EVENTS+86)
#define DISPID_EVPROP_ONACTIVATE           (DISPID_EVENTS+87)
#define DISPID_EVPROP_ONDEACTIVATE         (DISPID_EVENTS+88)
#define DISPID_EVPROP_ONMULTILAYOUTCLEANUP (DISPID_EVENTS+89)
#define DISPID_EVPROP_ONBEFOREACTIVATE     (DISPID_EVENTS+90)
#define DISPID_EVPROP_ONFOCUSIN            (DISPID_EVENTS+91)
#define DISPID_EVPROP_ONFOCUSOUT           (DISPID_EVENTS+92)
#define DISPID_EVPROPS_COUNT               93

#define DISPID_EVMETH_ONMOUSEOVER           STDDISPID_XOBJ_ONMOUSEOVER
#define DISPID_EVMETH_ONMOUSEOUT            STDDISPID_XOBJ_ONMOUSEOUT
#define DISPID_EVMETH_ONMOUSEDOWN           DISPID_MOUSEDOWN
#define DISPID_EVMETH_ONMOUSEUP             DISPID_MOUSEUP
#define DISPID_EVMETH_ONMOUSEMOVE           DISPID_MOUSEMOVE
#define DISPID_EVMETH_ONKEYDOWN             DISPID_KEYDOWN
#define DISPID_EVMETH_ONKEYUP               DISPID_KEYUP
#define DISPID_EVMETH_ONKEYPRESS            DISPID_KEYPRESS
#define DISPID_EVMETH_ONCLICK               DISPID_CLICK
#define DISPID_EVMETH_ONDBLCLICK            DISPID_DBLCLICK
#define DISPID_EVMETH_ONSELECT              DISPID_ONSELECT
#define DISPID_EVMETH_ONSUBMIT              DISPID_ONSUBMIT
#define DISPID_EVMETH_ONRESET               DISPID_ONRESET
#define DISPID_EVMETH_ONHELP                STDDISPID_XOBJ_ONHELP
#define DISPID_EVMETH_ONFOCUS               STDDISPID_XOBJ_ONFOCUS
#define DISPID_EVMETH_ONBLUR                STDDISPID_XOBJ_ONBLUR
#define DISPID_EVMETH_ONROWEXIT             STDDISPID_XOBJ_ONROWEXIT
#define DISPID_EVMETH_ONROWENTER            STDDISPID_XOBJ_ONROWENTER
#define DISPID_EVMETH_ONBOUNCE              DISPID_ONBOUNCE
#define DISPID_EVMETH_ONBEFOREUPDATE        STDDISPID_XOBJ_BEFOREUPDATE
#define DISPID_EVMETH_ONAFTERUPDATE         STDDISPID_XOBJ_AFTERUPDATE
#define DISPID_EVMETH_ONBEFOREDRAGOVER      EVENTID_CommonCtrlEvent_BeforeDragOver
#define DISPID_EVMETH_ONBEFOREDROPORPASTE   EVENTID_CommonCtrlEvent_BeforeDropOrPaste
#define DISPID_EVMETH_ONREADYSTATECHANGE    DISPID_READYSTATECHANGE
#define DISPID_EVMETH_ONFINISH              DISPID_ONFINISH
#define DISPID_EVMETH_ONSTART               DISPID_ONSTART
#define DISPID_EVMETH_ONABORT               DISPID_ONABORT
#define DISPID_EVMETH_ONERROR               DISPID_ONERROR
#define DISPID_EVMETH_ONCHANGE              DISPID_ONCHANGE
#define DISPID_EVMETH_ONSCROLL              DISPID_ONSCROLL
#define DISPID_EVMETH_ONLOAD                DISPID_ONLOAD
#define DISPID_EVMETH_ONUNLOAD              DISPID_ONUNLOAD
#define DISPID_EVMETH_ONLAYOUT              DISPID_ONLAYOUT
#define DISPID_EVMETH_ONDRAGSTART           STDDISPID_XOBJ_ONDRAGSTART
#define DISPID_EVMETH_ONRESIZE              DISPID_ONRESIZE
#define DISPID_EVMETH_ONSELECTSTART         STDDISPID_XOBJ_ONSELECTSTART
#define DISPID_EVMETH_ONERRORUPDATE         STDDISPID_XOBJ_ERRORUPDATE
#define DISPID_EVMETH_ONBEFOREUNLOAD        DISPID_ONBEFOREUNLOAD
#define DISPID_EVMETH_ONDATASETCHANGED      STDDISPID_XOBJ_ONDATASETCHANGED
#define DISPID_EVMETH_ONDATAAVAILABLE       STDDISPID_XOBJ_ONDATAAVAILABLE
#define DISPID_EVMETH_ONDATASETCOMPLETE     STDDISPID_XOBJ_ONDATASETCOMPLETE
#define DISPID_EVMETH_ONFILTER              STDDISPID_XOBJ_ONFILTER
#define DISPID_EVMETH_ONCHANGEFOCUS         DISPID_ONCHANGEFOCUS
#define DISPID_EVMETH_ONCHANGEBLUR          DISPID_ONCHANGEBLUR
#define DISPID_EVMETH_ONLOSECAPTURE         STDDISPID_XOBJ_ONLOSECAPTURE
#define DISPID_EVMETH_ONPROPERTYCHANGE      STDDISPID_XOBJ_ONPROPERTYCHANGE
#define DISPID_EVMETH_ONPERSISTSAVE         DISPID_ONPERSISTSAVE
#define DISPID_EVMETH_ONDRAG                STDDISPID_XOBJ_ONDRAG
#define DISPID_EVMETH_ONDRAGEND             STDDISPID_XOBJ_ONDRAGEND
#define DISPID_EVMETH_ONDRAGENTER           STDDISPID_XOBJ_ONDRAGENTER
#define DISPID_EVMETH_ONDRAGOVER            STDDISPID_XOBJ_ONDRAGOVER
#define DISPID_EVMETH_ONDRAGLEAVE           STDDISPID_XOBJ_ONDRAGLEAVE
#define DISPID_EVMETH_ONDROP                STDDISPID_XOBJ_ONDROP
#define DISPID_EVMETH_ONCUT                 STDDISPID_XOBJ_ONCUT
#define DISPID_EVMETH_ONCOPY                STDDISPID_XOBJ_ONCOPY
#define DISPID_EVMETH_ONPASTE               STDDISPID_XOBJ_ONPASTE
#define DISPID_EVMETH_ONBEFORECUT           STDDISPID_XOBJ_ONBEFORECUT
#define DISPID_EVMETH_ONBEFORECOPY          STDDISPID_XOBJ_ONBEFORECOPY
#define DISPID_EVMETH_ONBEFOREPASTE         STDDISPID_XOBJ_ONBEFOREPASTE
#define DISPID_EVMETH_ONPERSISTLOAD         DISPID_ONPERSISTLOAD
#define DISPID_EVMETH_ONROWSDELETE          STDDISPID_XOBJ_ONROWSDELETE
#define DISPID_EVMETH_ONROWSINSERTED        STDDISPID_XOBJ_ONROWSINSERTED
#define DISPID_EVMETH_ONCELLCHANGE          STDDISPID_XOBJ_ONCELLCHANGE
#define DISPID_EVMETH_ONCONTEXTMENU         DISPID_ONCONTEXTMENU
#define DISPID_EVMETH_ONBEFOREPRINT         DISPID_ONBEFOREPRINT
#define DISPID_EVMETH_ONAFTERPRINT          DISPID_ONAFTERPRINT
#define DISPID_EVMETH_ONSTOP                DISPID_ONSTOP
#define DISPID_EVMETH_ONBEFOREEDITFOCUS     DISPID_ONBEFOREEDITFOCUS
#define DISPID_EVMETH_ONMOUSEHOVER          DISPID_ONMOUSEHOVER
#define DISPID_EVMETH_ONCONTENTREADY        DISPID_ONCONTENTREADY
#define DISPID_EVMETH_ONLAYOUTCOMPLETE      DISPID_ONLAYOUTCOMPLETE
#define DISPID_EVMETH_ONPAGE                DISPID_ONPAGE
#define DISPID_EVMETH_ONLINKEDOVERFLOW      DISPID_ONLINKEDOVERFLOW
#define DISPID_EVMETH_ONMOUSEWHEEL          DISPID_ONMOUSEWHEEL
#define DISPID_EVMETH_ONBEFOREDEACTIVAT     DISPID_ONBEFOREDEACTIVATE
#define DISPID_EVMETH_ONMOVE                DISPID_ONMOVE
#define DISPID_EVMETH_ONCONTROLSELECT       DISPID_ONCONTROLSELECT
#define DISPID_EVMETH_ONSELECTIONCHANGE     DISPID_ONSELECTIONCHANGE
#define DISPID_EVMETH_ONMOVESTART           DISPID_ONMOVESTART
#define DISPID_EVMETH_ONMOVEEND             DISPID_ONMOVEEND
#define DISPID_EVMETH_ONRESIZESTART         DISPID_ONRESIZESTART
#define DISPID_EVMETH_ONRESIZEEND           DISPID_ONRESIZEEND
#define DISPID_EVMETH_ONMOUSEENTER          DISPID_ONMOUSEENTER
#define DISPID_EVMETH_ONMOUSELEAVE          DISPID_ONMOUSELEAVE
#define DISPID_EVMETH_ONACTIVATE            DISPID_ONACTIVATE
#define DISPID_EVMETH_ONDEACTIVATE          DISPID_ONDEACTIVATE
#define DISPID_EVMETH_ONMULTILAYOUTCLEANUP  DISPID_ONMULTILAYOUTCLEANUP
#define DISPID_EVMETH_ONBEFOREACTIVATE      DISPID_ONBEFOREACTIVATE
#define DISPID_EVMETH_ONFOCUSIN             DISPID_ONFOCUSIN
#define DISPID_EVMETH_ONFOCUSOUT            DISPID_ONFOCUSOUT
#define DISPID_EVPROPS_COUNT                93


#define DISPID_EVMETH_ONMOUSEOVER           STDDISPID_XOBJ_ONMOUSEOVER
#define DISPID_EVMETH_ONMOUSEOUT            STDDISPID_XOBJ_ONMOUSEOUT
#define DISPID_EVMETH_ONMOUSEDOWN           DISPID_MOUSEDOWN
#define DISPID_EVMETH_ONMOUSEUP             DISPID_MOUSEUP
#define DISPID_EVMETH_ONMOUSEMOVE           DISPID_MOUSEMOVE
#define DISPID_EVMETH_ONKEYDOWN             DISPID_KEYDOWN
#define DISPID_EVMETH_ONKEYUP               DISPID_KEYUP
#define DISPID_EVMETH_ONKEYPRESS            DISPID_KEYPRESS
#define DISPID_EVMETH_ONCLICK               DISPID_CLICK
#define DISPID_EVMETH_ONDBLCLICK            DISPID_DBLCLICK
#define DISPID_EVMETH_ONSELECT              DISPID_ONSELECT
#define DISPID_EVMETH_ONSUBMIT              DISPID_ONSUBMIT
#define DISPID_EVMETH_ONRESET               DISPID_ONRESET
#define DISPID_EVMETH_ONHELP                STDDISPID_XOBJ_ONHELP
#define DISPID_EVMETH_ONFOCUS               STDDISPID_XOBJ_ONFOCUS
#define DISPID_EVMETH_ONBLUR                STDDISPID_XOBJ_ONBLUR
#define DISPID_EVMETH_ONROWEXIT             STDDISPID_XOBJ_ONROWEXIT
#define DISPID_EVMETH_ONROWENTER            STDDISPID_XOBJ_ONROWENTER
#define DISPID_EVMETH_ONBOUNCE              DISPID_ONBOUNCE
#define DISPID_EVMETH_ONBEFOREUPDATE        STDDISPID_XOBJ_BEFOREUPDATE
#define DISPID_EVMETH_ONAFTERUPDATE         STDDISPID_XOBJ_AFTERUPDATE
#define DISPID_EVMETH_ONBEFOREDRAGOVER      EVENTID_CommonCtrlEvent_BeforeDragOver
#define DISPID_EVMETH_ONBEFOREDROPORPASTE   EVENTID_CommonCtrlEvent_BeforeDropOrPaste
#define DISPID_EVMETH_ONREADYSTATECHANGE    DISPID_READYSTATECHANGE
#define DISPID_EVMETH_ONFINISH              DISPID_ONFINISH
#define DISPID_EVMETH_ONSTART               DISPID_ONSTART
#define DISPID_EVMETH_ONABORT               DISPID_ONABORT
#define DISPID_EVMETH_ONERROR               DISPID_ONERROR
#define DISPID_EVMETH_ONCHANGE              DISPID_ONCHANGE
#define DISPID_EVMETH_ONSCROLL              DISPID_ONSCROLL
#define DISPID_EVMETH_ONLOAD                DISPID_ONLOAD
#define DISPID_EVMETH_ONUNLOAD              DISPID_ONUNLOAD
#define DISPID_EVMETH_ONLAYOUT              DISPID_ONLAYOUT
#define DISPID_EVMETH_ONDRAGSTART           STDDISPID_XOBJ_ONDRAGSTART
#define DISPID_EVMETH_ONRESIZE              DISPID_ONRESIZE
#define DISPID_EVMETH_ONSELECTSTART         STDDISPID_XOBJ_ONSELECTSTART
#define DISPID_EVMETH_ONERRORUPDATE         STDDISPID_XOBJ_ERRORUPDATE
#define DISPID_EVMETH_ONBEFOREUNLOAD        DISPID_ONBEFOREUNLOAD
#define DISPID_EVMETH_ONDATASETCHANGED      STDDISPID_XOBJ_ONDATASETCHANGED
#define DISPID_EVMETH_ONDATAAVAILABLE       STDDISPID_XOBJ_ONDATAAVAILABLE
#define DISPID_EVMETH_ONDATASETCOMPLETE     STDDISPID_XOBJ_ONDATASETCOMPLETE
#define DISPID_EVMETH_ONFILTER              STDDISPID_XOBJ_ONFILTER
#define DISPID_EVMETH_ONCHANGEFOCUS         DISPID_ONCHANGEFOCUS
#define DISPID_EVMETH_ONCHANGEBLUR          DISPID_ONCHANGEBLUR
#define DISPID_EVMETH_ONLOSECAPTURE         STDDISPID_XOBJ_ONLOSECAPTURE
#define DISPID_EVMETH_ONPROPERTYCHANGE      STDDISPID_XOBJ_ONPROPERTYCHANGE
#define DISPID_EVMETH_ONPERSISTSAVE         DISPID_ONPERSISTSAVE
#define DISPID_EVMETH_ONDRAG                STDDISPID_XOBJ_ONDRAG
#define DISPID_EVMETH_ONDRAGEND             STDDISPID_XOBJ_ONDRAGEND
#define DISPID_EVMETH_ONDRAGENTER           STDDISPID_XOBJ_ONDRAGENTER
#define DISPID_EVMETH_ONDRAGOVER            STDDISPID_XOBJ_ONDRAGOVER
#define DISPID_EVMETH_ONDRAGLEAVE           STDDISPID_XOBJ_ONDRAGLEAVE
#define DISPID_EVMETH_ONDROP                STDDISPID_XOBJ_ONDROP
#define DISPID_EVMETH_ONCUT                 STDDISPID_XOBJ_ONCUT
#define DISPID_EVMETH_ONCOPY                STDDISPID_XOBJ_ONCOPY
#define DISPID_EVMETH_ONPASTE               STDDISPID_XOBJ_ONPASTE
#define DISPID_EVMETH_ONBEFORECUT           STDDISPID_XOBJ_ONBEFORECUT
#define DISPID_EVMETH_ONBEFORECOPY          STDDISPID_XOBJ_ONBEFORECOPY
#define DISPID_EVMETH_ONBEFOREPASTE         STDDISPID_XOBJ_ONBEFOREPASTE
#define DISPID_EVMETH_ONPERSISTLOAD         DISPID_ONPERSISTLOAD
#define DISPID_EVMETH_ONROWSDELETE          STDDISPID_XOBJ_ONROWSDELETE
#define DISPID_EVMETH_ONROWSINSERTED        STDDISPID_XOBJ_ONROWSINSERTED
#define DISPID_EVMETH_ONCELLCHANGE          STDDISPID_XOBJ_ONCELLCHANGE
#define DISPID_EVMETH_ONCONTEXTMENU         DISPID_ONCONTEXTMENU
#define DISPID_EVMETH_ONBEFOREPRINT         DISPID_ONBEFOREPRINT
#define DISPID_EVMETH_ONAFTERPRINT          DISPID_ONAFTERPRINT
#define DISPID_EVMETH_ONSTOP                DISPID_ONSTOP
#define DISPID_EVMETH_ONBEFOREEDITFOCUS     DISPID_ONBEFOREEDITFOCUS
#define DISPID_EVMETH_ONMOUSEHOVER          DISPID_ONMOUSEHOVER
#define DISPID_EVMETH_ONCONTENTREADY        DISPID_ONCONTENTREADY
#define DISPID_EVMETH_ONLAYOUTCOMPLETE      DISPID_ONLAYOUTCOMPLETE
#define DISPID_EVMETH_ONPAGE                DISPID_ONPAGE
#define DISPID_EVMETH_ONLINKEDOVERFLOW      DISPID_ONLINKEDOVERFLOW
#define DISPID_EVMETH_ONMOUSEWHEEL          DISPID_ONMOUSEWHEEL
#define DISPID_EVMETH_ONBEFOREDEACTIVATE    DISPID_ONBEFOREDEACTIVATE
#define DISPID_EVMETH_ONMOVE                DISPID_ONMOVE
#define DISPID_EVMETH_ONCONTROLSELECT       DISPID_ONCONTROLSELECT
#define DISPID_EVMETH_ONSELECTIONCHANGE     DISPID_ONSELECTIONCHANGE
#define DISPID_EVMETH_ONMOVESTART           DISPID_ONMOVESTART
#define DISPID_EVMETH_ONMOVEEND             DISPID_ONMOVEEND
#define DISPID_EVMETH_ONRESIZESTART         DISPID_ONRESIZESTART
#define DISPID_EVMETH_ONRESIZEEND           DISPID_ONRESIZEEND
#define DISPID_EVMETH_ONMOUSEENTER          DISPID_ONMOUSEENTER
#define DISPID_EVMETH_ONMOUSELEAVE          DISPID_ONMOUSELEAVE
#define DISPID_EVMETH_ONACTIVATE            DISPID_ONACTIVATE
#define DISPID_EVMETH_ONDEACTIVATE          DISPID_ONDEACTIVATE
#define DISPID_EVMETH_ONMULTILAYOUTCLEANUP  DISPID_ONMULTILAYOUTCLEANUP
#define DISPID_EVMETH_ONBEFOREACTIVATE      DISPID_ONBEFOREACTIVATE
#define DISPID_EVMETH_ONFOCUSIN             DISPID_ONFOCUSIN
#define DISPID_EVMETH_ONFOCUSOUT            DISPID_ONFOCUSOUT

#define DISPID_ONABORT               (DISPID_NORMAL_FIRST)
#define DISPID_ONCHANGE              (DISPID_NORMAL_FIRST+1)
#define DISPID_ONERROR               (DISPID_NORMAL_FIRST+2)
#define DISPID_ONLOAD                (DISPID_NORMAL_FIRST+3)
#define DISPID_ONSELECT              (DISPID_NORMAL_FIRST+6)
#define DISPID_ONSUBMIT              (DISPID_NORMAL_FIRST+7)
#define DISPID_ONUNLOAD              (DISPID_NORMAL_FIRST+8)
#define DISPID_ONBOUNCE              (DISPID_NORMAL_FIRST+9)
#define DISPID_ONFINISH              (DISPID_NORMAL_FIRST+10)
#define DISPID_ONSTART               (DISPID_NORMAL_FIRST+11)
#define DISPID_ONLAYOUT              (DISPID_NORMAL_FIRST+13)
#define DISPID_ONSCROLL              (DISPID_NORMAL_FIRST+14)
#define DISPID_ONRESET               (DISPID_NORMAL_FIRST+15)
#define DISPID_ONRESIZE              (DISPID_NORMAL_FIRST+16)
#define DISPID_ONBEFOREUNLOAD        (DISPID_NORMAL_FIRST+17)
#define DISPID_ONCHANGEFOCUS         (DISPID_NORMAL_FIRST+18)
#define DISPID_ONCHANGEBLUR          (DISPID_NORMAL_FIRST+19)
#define DISPID_ONPERSIST             (DISPID_NORMAL_FIRST+20)
#define DISPID_ONPERSISTSAVE         (DISPID_NORMAL_FIRST+21)
#define DISPID_ONPERSISTLOAD         (DISPID_NORMAL_FIRST+22)
#define DISPID_ONCONTEXTMENU         (DISPID_NORMAL_FIRST+23)
#define DISPID_ONBEFOREPRINT         (DISPID_NORMAL_FIRST+24)
#define DISPID_ONAFTERPRINT          (DISPID_NORMAL_FIRST+25)
#define DISPID_ONSTOP                (DISPID_NORMAL_FIRST+26)
#define DISPID_ONBEFOREEDITFOCUS     (DISPID_NORMAL_FIRST+27)
#define DISPID_ONMOUSEHOVER          (DISPID_NORMAL_FIRST+28)
#define DISPID_ONCONTENTREADY        (DISPID_NORMAL_FIRST+29)
#define DISPID_ONLAYOUTCOMPLETE      (DISPID_NORMAL_FIRST+30)
#define DISPID_ONPAGE                (DISPID_NORMAL_FIRST+31)
#define DISPID_ONLINKEDOVERFLOW      (DISPID_NORMAL_FIRST+32)
#define DISPID_ONMOUSEWHEEL          (DISPID_NORMAL_FIRST+33)
#define DISPID_ONBEFOREDEACTIVATE    (DISPID_NORMAL_FIRST+34)
#define DISPID_ONMOVE                (DISPID_NORMAL_FIRST+35)
#define DISPID_ONCONTROLSELECT       (DISPID_NORMAL_FIRST+36)
#define DISPID_ONSELECTIONCHANGE     (DISPID_NORMAL_FIRST+37)
#define DISPID_ONMOVESTART           (DISPID_NORMAL_FIRST+38)
#define DISPID_ONMOVEEND             (DISPID_NORMAL_FIRST+39)
#define DISPID_ONRESIZESTART         (DISPID_NORMAL_FIRST+40)
#define DISPID_ONRESIZEEND           (DISPID_NORMAL_FIRST+41)
#define DISPID_ONMOUSEENTER          (DISPID_NORMAL_FIRST+42)
#define DISPID_ONMOUSELEAVE          (DISPID_NORMAL_FIRST+43)
#define DISPID_ONACTIVATE            (DISPID_NORMAL_FIRST+44)
#define DISPID_ONDEACTIVATE          (DISPID_NORMAL_FIRST+45)
#define DISPID_ONMULTILAYOUTCLEANUP  (DISPID_NORMAL_FIRST+46)
#define DISPID_ONBEFOREACTIVATE      (DISPID_NORMAL_FIRST+47)
#define DISPID_ONFOCUSIN             (DISPID_NORMAL_FIRST+48)
#define DISPID_ONFOCUSOUT            (DISPID_NORMAL_FIRST+49)

/* HTMLDocumentEvents */
#define DISPID_HTMLDOCUMENTEVENTS_ONHELP              DISPID_EVMETH_ONHELP
#define DISPID_HTMLDOCUMENTEVENTS_ONCLICK             DISPID_EVMETH_ONCLICK
#define DISPID_HTMLDOCUMENTEVENTS_ONDBLCLICK          DISPID_EVMETH_ONDBLCLICK
#define DISPID_HTMLDOCUMENTEVENTS_ONKEYDOWN           DISPID_EVMETH_ONKEYDOWN
#define DISPID_HTMLDOCUMENTEVENTS_ONKEYUP             DISPID_EVMETH_ONKEYUP
#define DISPID_HTMLDOCUMENTEVENTS_ONKEYPRESS          DISPID_EVMETH_ONKEYPRESS
#define DISPID_HTMLDOCUMENTEVENTS_ONMOUSEDOWN         DISPID_EVMETH_ONMOUSEDOWN
#define DISPID_HTMLDOCUMENTEVENTS_ONMOUSEMOVE         DISPID_EVMETH_ONMOUSEMOVE
#define DISPID_HTMLDOCUMENTEVENTS_ONMOUSEUP           DISPID_EVMETH_ONMOUSEUP
#define DISPID_HTMLDOCUMENTEVENTS_ONMOUSEOUT          DISPID_EVMETH_ONMOUSEOUT
#define DISPID_HTMLDOCUMENTEVENTS_ONMOUSEOVER         DISPID_EVMETH_ONMOUSEOVER
#define DISPID_HTMLDOCUMENTEVENTS_ONREADYSTATECHANGE  DISPID_EVMETH_ONREADYSTATECHANGE
#define DISPID_HTMLDOCUMENTEVENTS_ONBEFOREUPDATE      DISPID_EVMETH_ONBEFOREUPDATE
#define DISPID_HTMLDOCUMENTEVENTS_ONAFTERUPDATE       DISPID_EVMETH_ONAFTERUPDATE
#define DISPID_HTMLDOCUMENTEVENTS_ONROWEXIT           DISPID_EVMETH_ONROWEXIT
#define DISPID_HTMLDOCUMENTEVENTS_ONROWENTER          DISPID_EVMETH_ONROWENTER
#define DISPID_HTMLDOCUMENTEVENTS_ONDRAGSTART         DISPID_EVMETH_ONDRAGSTART
#define DISPID_HTMLDOCUMENTEVENTS_ONSELECTSTART       DISPID_EVMETH_ONSELECTSTART
#define DISPID_HTMLDOCUMENTEVENTS_ONERRORUPDATE       DISPID_EVMETH_ONERRORUPDATE
#define DISPID_HTMLDOCUMENTEVENTS_ONCONTEXTMENU       DISPID_EVMETH_ONCONTEXTMENU
#define DISPID_HTMLDOCUMENTEVENTS_ONSTOP              DISPID_EVMETH_ONSTOP
#define DISPID_HTMLDOCUMENTEVENTS_ONROWSDELETE        DISPID_EVMETH_ONROWSDELETE
#define DISPID_HTMLDOCUMENTEVENTS_ONROWSINSERTED      DISPID_EVMETH_ONROWSINSERTED
#define DISPID_HTMLDOCUMENTEVENTS_ONCELLCHANGE        DISPID_EVMETH_ONCELLCHANGE
#define DISPID_HTMLDOCUMENTEVENTS_ONPROPERTYCHANGE    DISPID_EVMETH_ONPROPERTYCHANGE
#define DISPID_HTMLDOCUMENTEVENTS_ONDATASETCHANGED    DISPID_EVMETH_ONDATASETCHANGED
#define DISPID_HTMLDOCUMENTEVENTS_ONDATAAVAILABLE     DISPID_EVMETH_ONDATAAVAILABLE
#define DISPID_HTMLDOCUMENTEVENTS_ONDATASETCOMPLETE   DISPID_EVMETH_ONDATASETCOMPLETE
#define DISPID_HTMLDOCUMENTEVENTS_ONBEFOREEDITFOCUS   DISPID_EVMETH_ONBEFOREEDITFOCUS
#define DISPID_HTMLDOCUMENTEVENTS_ONSELECTIONCHANGE   DISPID_EVMETH_ONSELECTIONCHANGE
#define DISPID_HTMLDOCUMENTEVENTS_ONCONTROLSELECT     DISPID_EVMETH_ONCONTROLSELECT
#define DISPID_HTMLDOCUMENTEVENTS_ONMOUSEWHEEL        DISPID_EVMETH_ONMOUSEWHEEL
#define DISPID_HTMLDOCUMENTEVENTS_ONFOCUSIN           DISPID_EVMETH_ONFOCUSIN
#define DISPID_HTMLDOCUMENTEVENTS_ONFOCUSOUT          DISPID_EVMETH_ONFOCUSOUT
#define DISPID_HTMLDOCUMENTEVENTS_ONACTIVATE          DISPID_EVMETH_ONACTIVATE
#define DISPID_HTMLDOCUMENTEVENTS_ONDEACTIVATE        DISPID_EVMETH_ONDEACTIVATE
#define DISPID_HTMLDOCUMENTEVENTS_ONBEFOREACTIVATE    DISPID_EVMETH_ONBEFOREACTIVATE
#define DISPID_HTMLDOCUMENTEVENTS_ONBEFOREDEACTIVATE  DISPID_EVMETH_ONBEFOREDEACTIVATE

/* HTMLDocumentEvents2 */
#define DISPID_HTMLDOCUMENTEVENTS2_ONHELP              DISPID_EVMETH_ONHELP
#define DISPID_HTMLDOCUMENTEVENTS2_ONCLICK             DISPID_EVMETH_ONCLICK
#define DISPID_HTMLDOCUMENTEVENTS2_ONDBLCLICK          DISPID_EVMETH_ONDBLCLICK
#define DISPID_HTMLDOCUMENTEVENTS2_ONKEYDOWN           DISPID_EVMETH_ONKEYDOWN
#define DISPID_HTMLDOCUMENTEVENTS2_ONKEYUP             DISPID_EVMETH_ONKEYUP
#define DISPID_HTMLDOCUMENTEVENTS2_ONKEYPRESS          DISPID_EVMETH_ONKEYPRESS
#define DISPID_HTMLDOCUMENTEVENTS2_ONMOUSEDOWN         DISPID_EVMETH_ONMOUSEDOWN
#define DISPID_HTMLDOCUMENTEVENTS2_ONMOUSEMOVE         DISPID_EVMETH_ONMOUSEMOVE
#define DISPID_HTMLDOCUMENTEVENTS2_ONMOUSEUP           DISPID_EVMETH_ONMOUSEUP
#define DISPID_HTMLDOCUMENTEVENTS2_ONMOUSEOUT          DISPID_EVMETH_ONMOUSEOUT
#define DISPID_HTMLDOCUMENTEVENTS2_ONMOUSEOVER         DISPID_EVMETH_ONMOUSEOVER
#define DISPID_HTMLDOCUMENTEVENTS2_ONREADYSTATECHANGE  DISPID_EVMETH_ONREADYSTATECHANGE
#define DISPID_HTMLDOCUMENTEVENTS2_ONBEFOREUPDATE      DISPID_EVMETH_ONBEFOREUPDATE
#define DISPID_HTMLDOCUMENTEVENTS2_ONAFTERUPDATE       DISPID_EVMETH_ONAFTERUPDATE
#define DISPID_HTMLDOCUMENTEVENTS2_ONROWEXIT           DISPID_EVMETH_ONROWEXIT
#define DISPID_HTMLDOCUMENTEVENTS2_ONROWENTER          DISPID_EVMETH_ONROWENTER
#define DISPID_HTMLDOCUMENTEVENTS2_ONDRAGSTART         DISPID_EVMETH_ONDRAGSTART
#define DISPID_HTMLDOCUMENTEVENTS2_ONSELECTSTART       DISPID_EVMETH_ONSELECTSTART
#define DISPID_HTMLDOCUMENTEVENTS2_ONERRORUPDATE       DISPID_EVMETH_ONERRORUPDATE
#define DISPID_HTMLDOCUMENTEVENTS2_ONCONTEXTMENU       DISPID_EVMETH_ONCONTEXTMENU
#define DISPID_HTMLDOCUMENTEVENTS2_ONSTOP              DISPID_EVMETH_ONSTOP
#define DISPID_HTMLDOCUMENTEVENTS2_ONROWSDELETE        DISPID_EVMETH_ONROWSDELETE
#define DISPID_HTMLDOCUMENTEVENTS2_ONROWSINSERTED      DISPID_EVMETH_ONROWSINSERTED
#define DISPID_HTMLDOCUMENTEVENTS2_ONCELLCHANGE        DISPID_EVMETH_ONCELLCHANGE
#define DISPID_HTMLDOCUMENTEVENTS2_ONPROPERTYCHANGE    DISPID_EVMETH_ONPROPERTYCHANGE
#define DISPID_HTMLDOCUMENTEVENTS2_ONDATASETCHANGED    DISPID_EVMETH_ONDATASETCHANGED
#define DISPID_HTMLDOCUMENTEVENTS2_ONDATAAVAILABLE     DISPID_EVMETH_ONDATAAVAILABLE
#define DISPID_HTMLDOCUMENTEVENTS2_ONDATASETCOMPLETE   DISPID_EVMETH_ONDATASETCOMPLETE
#define DISPID_HTMLDOCUMENTEVENTS2_ONBEFOREEDITFOCUS   DISPID_EVMETH_ONBEFOREEDITFOCUS
#define DISPID_HTMLDOCUMENTEVENTS2_ONSELECTIONCHANGE   DISPID_EVMETH_ONSELECTIONCHANGE
#define DISPID_HTMLDOCUMENTEVENTS2_ONCONTROLSELECT     DISPID_EVMETH_ONCONTROLSELECT
#define DISPID_HTMLDOCUMENTEVENTS2_ONMOUSEWHEEL        DISPID_EVMETH_ONMOUSEWHEEL
#define DISPID_HTMLDOCUMENTEVENTS2_ONFOCUSIN           DISPID_EVMETH_ONFOCUSIN
#define DISPID_HTMLDOCUMENTEVENTS2_ONFOCUSOUT          DISPID_EVMETH_ONFOCUSOUT
#define DISPID_HTMLDOCUMENTEVENTS2_ONACTIVATE          DISPID_EVMETH_ONACTIVATE
#define DISPID_HTMLDOCUMENTEVENTS2_ONDEACTIVATE        DISPID_EVMETH_ONDEACTIVATE
#define DISPID_HTMLDOCUMENTEVENTS2_ONBEFOREACTIVATE    DISPID_EVMETH_ONBEFOREACTIVATE
#define DISPID_HTMLDOCUMENTEVENTS2_ONBEFOREDEACTIVATE  DISPID_EVMETH_ONBEFOREDEACTIVATE

/* IHTMLDocument */
#define DISPID_IHTMLDOCUMENT_SCRIPT    (DISPID_OMDOCUMENT+1)

/* IHTMLDocument2 */
#define DISPID_IHTMLDOCUMENT2_ALL                     (DISPID_OMDOCUMENT+3)
#define DISPID_IHTMLDOCUMENT2_BODY                    (DISPID_OMDOCUMENT+4)
#define DISPID_IHTMLDOCUMENT2_ACTIVEELEMENT           (DISPID_OMDOCUMENT+5)
#define DISPID_IHTMLDOCUMENT2_APPLETS                 (DISPID_OMDOCUMENT+8)
#define DISPID_IHTMLDOCUMENT2_ANCHORS                 (DISPID_OMDOCUMENT+7)
#define DISPID_IHTMLDOCUMENT2_LINKS                   (DISPID_OMDOCUMENT+9)
#define DISPID_IHTMLDOCUMENT2_FORMS                   (DISPID_OMDOCUMENT+10)
#define DISPID_IHTMLDOCUMENT2_IMAGES                  (DISPID_OMDOCUMENT+11)
#define DISPID_IHTMLDOCUMENT2_TITLE                   (DISPID_OMDOCUMENT+12)
#define DISPID_IHTMLDOCUMENT2_SCRIPTS                 (DISPID_OMDOCUMENT+13)
#define DISPID_IHTMLDOCUMENT2_DESIGNMODE              (DISPID_OMDOCUMENT+14)
#define DISPID_IHTMLDOCUMENT2_EMBEDS                  (DISPID_OMDOCUMENT+15)
#define DISPID_IHTMLDOCUMENT2_SELECTION               (DISPID_OMDOCUMENT+17)
#define DISPID_IHTMLDOCUMENT2_READYSTATE              (DISPID_OMDOCUMENT+18)
#define DISPID_IHTMLDOCUMENT2_FRAMES                  (DISPID_OMDOCUMENT+19)
#define DISPID_IHTMLDOCUMENT2_PLUGINS                 (DISPID_OMDOCUMENT+21)
#define DISPID_IHTMLDOCUMENT2_ALINKCOLOR              (DISPID_OMDOCUMENT+22)
#define DISPID_IHTMLDOCUMENT2_VLINKCOLOR              (DISPID_OMDOCUMENT+23)
#define DISPID_IHTMLDOCUMENT2_LINKCOLOR               (DISPID_OMDOCUMENT+24)
#define DISPID_IHTMLDOCUMENT2_URL                     (DISPID_OMDOCUMENT+25)
#define DISPID_IHTMLDOCUMENT2_LOCATION                (DISPID_OMDOCUMENT+26)
#define DISPID_IHTMLDOCUMENT2_REFERRER                (DISPID_OMDOCUMENT+27)
#define DISPID_IHTMLDOCUMENT2_LASTMODIFIED            (DISPID_OMDOCUMENT+28)
#define DISPID_IHTMLDOCUMENT2_DOMAIN                  (DISPID_OMDOCUMENT+29)
#define DISPID_IHTMLDOCUMENT2_COOKIE                  (DISPID_OMDOCUMENT+30)
#define DISPID_IHTMLDOCUMENT2_EXPANDO                 (DISPID_OMDOCUMENT+31)
#define DISPID_IHTMLDOCUMENT2_CHARSET                 (DISPID_OMDOCUMENT+32)
#define DISPID_IHTMLDOCUMENT2_DEFAULTCHARSET          (DISPID_OMDOCUMENT+33)
#define DISPID_IHTMLDOCUMENT2_PARENTWINDOW            (DISPID_OMDOCUMENT+34)
#define DISPID_IHTMLDOCUMENT2_MIMETYPE                (DISPID_OMDOCUMENT+41)
#define DISPID_IHTMLDOCUMENT2_FILESIZE                (DISPID_OMDOCUMENT+42)
#define DISPID_IHTMLDOCUMENT2_FILECREATEDDATE         (DISPID_OMDOCUMENT+43)
#define DISPID_IHTMLDOCUMENT2_FILEMODIFIEDDATE        (DISPID_OMDOCUMENT+44)
#define DISPID_IHTMLDOCUMENT2_FILEUPDATEDDATE         (DISPID_OMDOCUMENT+45)
#define DISPID_IHTMLDOCUMENT2_SECURITY                (DISPID_OMDOCUMENT+46)
#define DISPID_IHTMLDOCUMENT2_PROTOCOL                (DISPID_OMDOCUMENT+47)
#define DISPID_IHTMLDOCUMENT2_NAMEPROP                (DISPID_OMDOCUMENT+48)
#define DISPID_IHTMLDOCUMENT2_WRITE                   (DISPID_OMDOCUMENT+54)
#define DISPID_IHTMLDOCUMENT2_WRITELN                 (DISPID_OMDOCUMENT+55)
#define DISPID_IHTMLDOCUMENT2_OPEN                    (DISPID_OMDOCUMENT+56)
#define DISPID_IHTMLDOCUMENT2_CLOSE                   (DISPID_OMDOCUMENT+57)
#define DISPID_IHTMLDOCUMENT2_CLEAR                   (DISPID_OMDOCUMENT+58)
#define DISPID_IHTMLDOCUMENT2_QUERYCOMMANDSUPPORTED   (DISPID_OMDOCUMENT+59)
#define DISPID_IHTMLDOCUMENT2_QUERYCOMMANDENABLED     (DISPID_OMDOCUMENT+60)
#define DISPID_IHTMLDOCUMENT2_QUERYCOMMANDSTATE       (DISPID_OMDOCUMENT+61)
#define DISPID_IHTMLDOCUMENT2_QUERYCOMMANDINDETERM    (DISPID_OMDOCUMENT+62)
#define DISPID_IHTMLDOCUMENT2_QUERYCOMMANDTEXT        (DISPID_OMDOCUMENT+63)
#define DISPID_IHTMLDOCUMENT2_QUERYCOMMANDVALUE       (DISPID_OMDOCUMENT+64)
#define DISPID_IHTMLDOCUMENT2_EXECCOMMAND             (DISPID_OMDOCUMENT+65)
#define DISPID_IHTMLDOCUMENT2_EXECCOMMANDSHOWHELP     (DISPID_OMDOCUMENT+66)
#define DISPID_IHTMLDOCUMENT2_CREATEELEMENT           (DISPID_OMDOCUMENT+67)
#define DISPID_IHTMLDOCUMENT2_ELEMENTFROMPOINT        (DISPID_OMDOCUMENT+68)
#define DISPID_IHTMLDOCUMENT2_STYLESHEETS             (DISPID_OMDOCUMENT+69)
#define DISPID_IHTMLDOCUMENT2_TOSTRING                (DISPID_OMDOCUMENT+70)
#define DISPID_IHTMLDOCUMENT2_CREATESTYLESHEET        (DISPID_OMDOCUMENT+71)
#define DISPID_IHTMLDOCUMENT2_ONHELP                  DISPID_EVPROP_ONHELP
#define DISPID_IHTMLDOCUMENT2_ONCLICK                 DISPID_EVPROP_ONCLICK
#define DISPID_IHTMLDOCUMENT2_ONDBLCLICK              DISPID_EVPROP_ONDBLCLICK
#define DISPID_IHTMLDOCUMENT2_ONKEYUP                 DISPID_EVPROP_ONKEYUP
#define DISPID_IHTMLDOCUMENT2_ONKEYDOWN               DISPID_EVPROP_ONKEYDOWN
#define DISPID_IHTMLDOCUMENT2_ONKEYPRESS              DISPID_EVPROP_ONKEYPRESS
#define DISPID_IHTMLDOCUMENT2_ONMOUSEUP               DISPID_EVPROP_ONMOUSEUP
#define DISPID_IHTMLDOCUMENT2_ONMOUSEDOWN             DISPID_EVPROP_ONMOUSEDOWN
#define DISPID_IHTMLDOCUMENT2_ONMOUSEMOVE             DISPID_EVPROP_ONMOUSEMOVE
#define DISPID_IHTMLDOCUMENT2_ONMOUSEOUT              DISPID_EVPROP_ONMOUSEOUT
#define DISPID_IHTMLDOCUMENT2_ONMOUSEOVER             DISPID_EVPROP_ONMOUSEOVER
#define DISPID_IHTMLDOCUMENT2_ONREADYSTATECHANGE      DISPID_EVPROP_ONREADYSTATECHANGE
#define DISPID_IHTMLDOCUMENT2_ONAFTERUPDATE           DISPID_EVPROP_ONAFTERUPDATE
#define DISPID_IHTMLDOCUMENT2_ONROWEXIT               DISPID_EVPROP_ONROWEXIT
#define DISPID_IHTMLDOCUMENT2_ONROWENTER              DISPID_EVPROP_ONROWENTER
#define DISPID_IHTMLDOCUMENT2_ONDRAGSTART             DISPID_EVPROP_ONDRAGSTART
#define DISPID_IHTMLDOCUMENT2_ONSELECTSTART           DISPID_EVPROP_ONSELECTSTART
#define DISPID_IHTMLDOCUMENT2_ONBEFOREUPDATE          DISPID_EVPROP_ONBEFOREUPDATE
#define DISPID_IHTMLDOCUMENT2_ONERRORUPDATE           DISPID_EVPROP_ONERRORUPDATE
#define DISPID_IHTMLDOCUMENT2_BGCOLOR                 DISPID_BACKCOLOR
#define DISPID_IHTMLDOCUMENT2_FGCOLOR                 DISPID_A_COLOR

/* IHTMLDocument3 */
#define DISPID_IHTMLDOCUMENT3_RELEASECAPTURE          DISPID_OMDOCUMENT+72
#define DISPID_IHTMLDOCUMENT3_RECALC                  DISPID_OMDOCUMENT+73
#define DISPID_IHTMLDOCUMENT3_CREATETEXTNODE          DISPID_OMDOCUMENT+74
#define DISPID_IHTMLDOCUMENT3_DOCUMENTELEMENT         DISPID_OMDOCUMENT+75
#define DISPID_IHTMLDOCUMENT3_UNIQUEID                DISPID_OMDOCUMENT+77
#define DISPID_IHTMLDOCUMENT3_ATTACHEVENT             DISPID_HTMLOBJECT+7
#define DISPID_IHTMLDOCUMENT3_DETACHEVENT             DISPID_HTMLOBJECT+8
#define DISPID_IHTMLDOCUMENT3_ONROWSDELETE            DISPID_EVPROP_ONROWSDELETE
#define DISPID_IHTMLDOCUMENT3_ONROWSINSERTED          DISPID_EVPROP_ONROWSINSERTED
#define DISPID_IHTMLDOCUMENT3_ONCELLCHANGE            DISPID_EVPROP_ONCELLCHANGE
#define DISPID_IHTMLDOCUMENT3_ONDATASETCHANGED        DISPID_EVPROP_ONDATASETCHANGED
#define DISPID_IHTMLDOCUMENT3_ONDATAAVAILABLE         DISPID_EVPROP_ONDATAAVAILABLE
#define DISPID_IHTMLDOCUMENT3_ONDATASETCOMPLETE       DISPID_EVPROP_ONDATASETCOMPLETE
#define DISPID_IHTMLDOCUMENT3_ONPROPERTYCHANGE        DISPID_EVPROP_ONPROPERTYCHANGE
#define DISPID_IHTMLDOCUMENT3_DIR                     DISPID_A_DIR
#define DISPID_IHTMLDOCUMENT3_ONCONTEXTMENU           DISPID_EVPROP_ONCONTEXTMENU
#define DISPID_IHTMLDOCUMENT3_ONSTOP                  DISPID_EVPROP_ONSTOP
#define DISPID_IHTMLDOCUMENT3_CREATEDOCUMENTFRAGMENT  DISPID_OMDOCUMENT+76
#define DISPID_IHTMLDOCUMENT3_PARENTDOCUMENT          DISPID_OMDOCUMENT+78
#define DISPID_IHTMLDOCUMENT3_ENABLEDOWNLOAD          DISPID_OMDOCUMENT+79
#define DISPID_IHTMLDOCUMENT3_BASEURL                 DISPID_OMDOCUMENT+80
#define DISPID_IHTMLDOCUMENT3_CHILDNODES              DISPID_ELEMENT+49
#define DISPID_IHTMLDOCUMENT3_INHERITSTYLESHEETS      DISPID_OMDOCUMENT+82
#define DISPID_IHTMLDOCUMENT3_ONBEFOREEDITFOCUS       DISPID_EVPROP_ONBEFOREEDITFOCUS
#define DISPID_IHTMLDOCUMENT3_GETELEMENTSBYNAME       DISPID_OMDOCUMENT+86
#define DISPID_IHTMLDOCUMENT3_GETELEMENTBYID          DISPID_OMDOCUMENT+88
#define DISPID_IHTMLDOCUMENT3_GETELEMENTSBYTAGNAME    DISPID_OMDOCUMENT+87


/* IHTMLDocument4 */
#define DISPID_IHTMLDOCUMENT4_FOCUS                  DISPID_OMDOCUMENT+89
#define DISPID_IHTMLDOCUMENT4_HASFOCUS               DISPID_OMDOCUMENT+90
#define DISPID_IHTMLDOCUMENT4_ONSELECTIONCHANGE      DISPID_EVPROP_ONSELECTIONCHANGE
#define DISPID_IHTMLDOCUMENT4_NAMESPACES             DISPID_OMDOCUMENT+91
#define DISPID_IHTMLDOCUMENT4_CREATEDOCUMENTFROMURL  DISPID_OMDOCUMENT+92
#define DISPID_IHTMLDOCUMENT4_MEDIA                  DISPID_OMDOCUMENT+93
#define DISPID_IHTMLDOCUMENT4_CREATEEVENTOBJECT      DISPID_OMDOCUMENT+94
#define DISPID_IHTMLDOCUMENT4_FIREEVENT              DISPID_OMDOCUMENT+95
#define DISPID_IHTMLDOCUMENT4_CREATERENDERSTYLE      DISPID_OMDOCUMENT+96
#define DISPID_IHTMLDOCUMENT4_ONCONTROLSELECT        DISPID_EVPROP_ONCONTROLSELECT
#define DISPID_IHTMLDOCUMENT4_URLUNENCODED           DISPID_OMDOCUMENT+97

/* IHTMLDocument5 */
#define DISPID_IHTMLDOCUMENT5_ONMOUSEWHEEL        DISPID_EVPROP_ONMOUSEWHEEL
#define DISPID_IHTMLDOCUMENT5_DOCTYPE             DISPID_OMDOCUMENT+98
#define DISPID_IHTMLDOCUMENT5_IMPLEMENTATION      DISPID_OMDOCUMENT+99
#define DISPID_IHTMLDOCUMENT5_CREATEATTRIBUTE     DISPID_OMDOCUMENT+100
#define DISPID_IHTMLDOCUMENT5_CREATECOMMENT       DISPID_OMDOCUMENT+101
#define DISPID_IHTMLDOCUMENT5_ONFOCUSIN           DISPID_EVPROP_ONFOCUSIN
#define DISPID_IHTMLDOCUMENT5_ONFOCUSOUT          DISPID_EVPROP_ONFOCUSOUT
#define DISPID_IHTMLDOCUMENT5_ONACTIVATE          DISPID_EVPROP_ONACTIVATE
#define DISPID_IHTMLDOCUMENT5_ONDEACTIVATE        DISPID_EVPROP_ONDEACTIVATE
#define DISPID_IHTMLDOCUMENT5_ONBEFOREACTIVATE    DISPID_EVPROP_ONBEFOREACTIVATE
#define DISPID_IHTMLDOCUMENT5_ONBEFOREDEACTIVATE  DISPID_EVPROP_ONBEFOREDEACTIVATE
#define DISPID_IHTMLDOCUMENT5_COMPATMODE          DISPID_OMDOCUMENT+102


/* IHTMLElementCollection */
#define DISPID_IHTMLELEMENTCOLLECTION_LENGTH     DISPID_COLLECTION
#define DISPID_IHTMLELEMENTCOLLECTION_TOSTRING   (DISPID_COLLECTION+1)
#define DISPID_IHTMLELEMENTCOLLECTION_TAGS       (DISPID_COLLECTION+2)
#define DISPID_IHTMLELEMENTCOLLECTION__NEWENUM   DISPID_NEWENUM
#define DISPID_IHTMLELEMENTCOLLECTION_ITEM       DISPID_VALUE

/* HTMLElementEvents */
#define DISPID_HTMLELEMENTEVENTS_ONHELP             DISPID_EVMETH_ONHELP
#define DISPID_HTMLELEMENTEVENTS_ONCLICK            DISPID_EVMETH_ONCLICK
#define DISPID_HTMLELEMENTEVENTS_ONDBLCLICK         DISPID_EVMETH_ONDBLCLICK
#define DISPID_HTMLELEMENTEVENTS_ONKEYPRESS         DISPID_EVMETH_ONKEYPRESS
#define DISPID_HTMLELEMENTEVENTS_ONKEYDOWN          DISPID_EVMETH_ONKEYDOWN
#define DISPID_HTMLELEMENTEVENTS_ONKEYUP            DISPID_EVMETH_ONKEYUP
#define DISPID_HTMLELEMENTEVENTS_ONMOUSEOUT         DISPID_EVMETH_ONMOUSEOUT
#define DISPID_HTMLELEMENTEVENTS_ONMOUSEOVER        DISPID_EVMETH_ONMOUSEOVER
#define DISPID_HTMLELEMENTEVENTS_ONMOUSEMOVE        DISPID_EVMETH_ONMOUSEMOVE
#define DISPID_HTMLELEMENTEVENTS_ONMOUSEDOWN        DISPID_EVMETH_ONMOUSEDOWN
#define DISPID_HTMLELEMENTEVENTS_ONMOUSEUP          DISPID_EVMETH_ONMOUSEUP
#define DISPID_HTMLELEMENTEVENTS_ONSELECTSTART      DISPID_EVMETH_ONSELECTSTART
#define DISPID_HTMLELEMENTEVENTS_ONFILTERCHANGE     DISPID_EVMETH_ONFILTER
#define DISPID_HTMLELEMENTEVENTS_ONDRAGSTART        DISPID_EVMETH_ONDRAGSTART
#define DISPID_HTMLELEMENTEVENTS_ONBEFOREUPDATE     DISPID_EVMETH_ONBEFOREUPDATE
#define DISPID_HTMLELEMENTEVENTS_ONAFTERUPDATE      DISPID_EVMETH_ONAFTERUPDATE
#define DISPID_HTMLELEMENTEVENTS_ONERRORUPDATE      DISPID_EVMETH_ONERRORUPDATE
#define DISPID_HTMLELEMENTEVENTS_ONROWEXIT          DISPID_EVMETH_ONROWEXIT
#define DISPID_HTMLELEMENTEVENTS_ONROWENTER         DISPID_EVMETH_ONROWENTER
#define DISPID_HTMLELEMENTEVENTS_ONDATASETCHANGED   DISPID_EVMETH_ONDATASETCHANGED
#define DISPID_HTMLELEMENTEVENTS_ONDATAAVAILABLE    DISPID_EVMETH_ONDATAAVAILABLE
#define DISPID_HTMLELEMENTEVENTS_ONDATASETCOMPLETE  DISPID_EVMETH_ONDATASETCOMPLETE
#define DISPID_HTMLELEMENTEVENTS_ONLOSECAPTURE      DISPID_EVMETH_ONLOSECAPTURE
#define DISPID_HTMLELEMENTEVENTS_ONPROPERTYCHANGE   DISPID_EVMETH_ONPROPERTYCHANGE
#define DISPID_HTMLELEMENTEVENTS_ONSCROLL           DISPID_EVMETH_ONSCROLL
#define DISPID_HTMLELEMENTEVENTS_ONFOCUS            DISPID_EVMETH_ONFOCUS
#define DISPID_HTMLELEMENTEVENTS_ONBLUR             DISPID_EVMETH_ONBLUR
#define DISPID_HTMLELEMENTEVENTS_ONRESIZE           DISPID_EVMETH_ONRESIZE
#define DISPID_HTMLELEMENTEVENTS_ONDRAG             DISPID_EVMETH_ONDRAG
#define DISPID_HTMLELEMENTEVENTS_ONDRAGEND          DISPID_EVMETH_ONDRAGEND
#define DISPID_HTMLELEMENTEVENTS_ONDRAGENTER        DISPID_EVMETH_ONDRAGENTER
#define DISPID_HTMLELEMENTEVENTS_ONDRAGOVER         DISPID_EVMETH_ONDRAGOVER
#define DISPID_HTMLELEMENTEVENTS_ONDRAGLEAVE        DISPID_EVMETH_ONDRAGLEAVE
#define DISPID_HTMLELEMENTEVENTS_ONDROP             DISPID_EVMETH_ONDROP
#define DISPID_HTMLELEMENTEVENTS_ONBEFORECUT        DISPID_EVMETH_ONBEFORECUT
#define DISPID_HTMLELEMENTEVENTS_ONCUT              DISPID_EVMETH_ONCUT
#define DISPID_HTMLELEMENTEVENTS_ONBEFORECOPY       DISPID_EVMETH_ONBEFORECOPY
#define DISPID_HTMLELEMENTEVENTS_ONCOPY             DISPID_EVMETH_ONCOPY
#define DISPID_HTMLELEMENTEVENTS_ONBEFOREPASTE      DISPID_EVMETH_ONBEFOREPASTE
#define DISPID_HTMLELEMENTEVENTS_ONPASTE            DISPID_EVMETH_ONPASTE
#define DISPID_HTMLELEMENTEVENTS_ONCONTEXTMENU      DISPID_EVMETH_ONCONTEXTMENU
#define DISPID_HTMLELEMENTEVENTS_ONROWSDELETE       DISPID_EVMETH_ONROWSDELETE
#define DISPID_HTMLELEMENTEVENTS_ONROWSINSERTED     DISPID_EVMETH_ONROWSINSERTED
#define DISPID_HTMLELEMENTEVENTS_ONCELLCHANGE       DISPID_EVMETH_ONCELLCHANGE
#define DISPID_HTMLELEMENTEVENTS_ONREADYSTATECHANGE DISPID_EVMETH_ONREADYSTATECHANGE
#define DISPID_HTMLELEMENTEVENTS_ONBEFOREEDITFOCUS  DISPID_EVMETH_ONBEFOREEDITFOCUS
#define DISPID_HTMLELEMENTEVENTS_ONLAYOUTCOMPLETE   DISPID_EVMETH_ONLAYOUTCOMPLETE
#define DISPID_HTMLELEMENTEVENTS_ONPAGE             DISPID_EVMETH_ONPAGE
#define DISPID_HTMLELEMENTEVENTS_ONBEFOREDEACTIVATE DISPID_EVMETH_ONBEFOREDEACTIVATE
#define DISPID_HTMLELEMENTEVENTS_ONBEFOREACTIVATE   DISPID_EVMETH_ONBEFOREACTIVATE
#define DISPID_HTMLELEMENTEVENTS_ONMOVE             DISPID_EVMETH_ONMOVE
#define DISPID_HTMLELEMENTEVENTS_ONCONTROLSELECT    DISPID_EVMETH_ONCONTROLSELECT
#define DISPID_HTMLELEMENTEVENTS_ONMOVESTART        DISPID_EVMETH_ONMOVESTART
#define DISPID_HTMLELEMENTEVENTS_ONMOVEEND          DISPID_EVMETH_ONMOVEEND
#define DISPID_HTMLELEMENTEVENTS_ONRESIZESTART      DISPID_EVMETH_ONRESIZESTART
#define DISPID_HTMLELEMENTEVENTS_ONRESIZEEND        DISPID_EVMETH_ONRESIZEEND
#define DISPID_HTMLELEMENTEVENTS_ONMOUSEENTER       DISPID_EVMETH_ONMOUSEENTER
#define DISPID_HTMLELEMENTEVENTS_ONMOUSELEAVE       DISPID_EVMETH_ONMOUSELEAVE
#define DISPID_HTMLELEMENTEVENTS_ONMOUSEWHEEL       DISPID_EVMETH_ONMOUSEWHEEL
#define DISPID_HTMLELEMENTEVENTS_ONACTIVATE         DISPID_EVMETH_ONACTIVATE
#define DISPID_HTMLELEMENTEVENTS_ONDEACTIVATE       DISPID_EVMETH_ONDEACTIVATE
#define DISPID_HTMLELEMENTEVENTS_ONFOCUSIN          DISPID_EVMETH_ONFOCUSIN
#define DISPID_HTMLELEMENTEVENTS_ONFOCUSOUT         DISPID_EVMETH_ONFOCUSOUT

/* IHTMLElement */
#define DISPID_IHTMLELEMENT_SETATTRIBUTE         (DISPID_HTMLOBJECT+1)
#define DISPID_IHTMLELEMENT_GETATTRIBUTE         (DISPID_HTMLOBJECT+2)
#define DISPID_IHTMLELEMENT_REMOVEATTRIBUTE      (DISPID_HTMLOBJECT+3)
#define DISPID_IHTMLELEMENT_CLASSNAME            (DISPID_ELEMENT+1)
#define DISPID_IHTMLELEMENT_ID                   (DISPID_ELEMENT+2)
#define DISPID_IHTMLELEMENT_TAGNAME              (DISPID_ELEMENT+4)
#define DISPID_IHTMLELEMENT_OFFSETLEFT           (DISPID_ELEMENT+8)
#define DISPID_IHTMLELEMENT_OFFSETTOP            (DISPID_ELEMENT+9)
#define DISPID_IHTMLELEMENT_OFFSETWIDTH          (DISPID_ELEMENT+10)
#define DISPID_IHTMLELEMENT_OFFSETHEIGHT         (DISPID_ELEMENT+11)
#define DISPID_IHTMLELEMENT_OFFSETPARENT         (DISPID_ELEMENT+12)
#define DISPID_IHTMLELEMENT_DOCUMENT             (DISPID_ELEMENT+18)
#define DISPID_IHTMLELEMENT_SCROLLINTOVIEW       (DISPID_ELEMENT+19)
#define DISPID_IHTMLELEMENT_CONTAINS             (DISPID_ELEMENT+20)
#define DISPID_IHTMLELEMENT_SOURCEINDEX          (DISPID_ELEMENT+24)
#define DISPID_IHTMLELEMENT_RECORDNUMBER         (DISPID_ELEMENT+25)
#define DISPID_IHTMLELEMENT_INNERHTML            (DISPID_ELEMENT+26)
#define DISPID_IHTMLELEMENT_INNERTEXT            (DISPID_ELEMENT+27)
#define DISPID_IHTMLELEMENT_OUTERHTML            (DISPID_ELEMENT+28)
#define DISPID_IHTMLELEMENT_OUTERTEXT            (DISPID_ELEMENT+29)
#define DISPID_IHTMLELEMENT_INSERTADJACENTHTML   (DISPID_ELEMENT+30)
#define DISPID_IHTMLELEMENT_INSERTADJACENTTEXT   (DISPID_ELEMENT+31)
#define DISPID_IHTMLELEMENT_PARENTTEXTEDIT       (DISPID_ELEMENT+32)
#define DISPID_IHTMLELEMENT_ISTEXTEDIT           (DISPID_ELEMENT+34)
#define DISPID_IHTMLELEMENT_CLICK                (DISPID_ELEMENT+33)
#define DISPID_IHTMLELEMENT_FILTERS              (DISPID_ELEMENT+35)
#define DISPID_IHTMLELEMENT_TOSTRING             (DISPID_ELEMENT+36)
#define DISPID_IHTMLELEMENT_CHILDREN             (DISPID_ELEMENT+37)
#define DISPID_IHTMLELEMENT_ALL                  (DISPID_ELEMENT+38)
#define DISPID_IHTMLELEMENT_PARENTELEMENT        STDPROPID_XOBJ_PARENT
#define DISPID_IHTMLELEMENT_STYLE                STDPROPID_XOBJ_STYLE
#define DISPID_IHTMLELEMENT_ONHELP               DISPID_EVPROP_ONHELP
#define DISPID_IHTMLELEMENT_ONCLICK              DISPID_EVPROP_ONCLICK
#define DISPID_IHTMLELEMENT_ONDBLCLICK           DISPID_EVPROP_ONDBLCLICK
#define DISPID_IHTMLELEMENT_ONKEYDOWN            DISPID_EVPROP_ONKEYDOWN
#define DISPID_IHTMLELEMENT_ONKEYUP              DISPID_EVPROP_ONKEYUP
#define DISPID_IHTMLELEMENT_ONKEYPRESS           DISPID_EVPROP_ONKEYPRESS
#define DISPID_IHTMLELEMENT_ONMOUSEOUT           DISPID_EVPROP_ONMOUSEOUT
#define DISPID_IHTMLELEMENT_ONMOUSEOVER          DISPID_EVPROP_ONMOUSEOVER
#define DISPID_IHTMLELEMENT_ONMOUSEMOVE          DISPID_EVPROP_ONMOUSEMOVE
#define DISPID_IHTMLELEMENT_ONMOUSEDOWN          DISPID_EVPROP_ONMOUSEDOWN
#define DISPID_IHTMLELEMENT_ONMOUSEUP            DISPID_EVPROP_ONMOUSEUP
#define DISPID_IHTMLELEMENT_TITLE                STDPROPID_XOBJ_CONTROLTIPTEXT
#define DISPID_IHTMLELEMENT_LANGUAGE             DISPID_A_LANGUAGE
#define DISPID_IHTMLELEMENT_ONSELECTSTART        DISPID_EVPROP_ONSELECTSTART
#define DISPID_IHTMLELEMENT_LANG                 DISPID_A_LANG
#define DISPID_IHTMLELEMENT_ONDRAGSTART          DISPID_EVPROP_ONDRAGSTART
#define DISPID_IHTMLELEMENT_ONBEFOREUPDATE       DISPID_EVPROP_ONBEFOREUPDATE
#define DISPID_IHTMLELEMENT_ONAFTERUPDATE        DISPID_EVPROP_ONAFTERUPDATE
#define DISPID_IHTMLELEMENT_ONERRORUPDATE        DISPID_EVPROP_ONERRORUPDATE
#define DISPID_IHTMLELEMENT_ONROWEXIT            DISPID_EVPROP_ONROWEXIT
#define DISPID_IHTMLELEMENT_ONROWENTER           DISPID_EVPROP_ONROWENTER
#define DISPID_IHTMLELEMENT_ONDATASETCHANGED     DISPID_EVPROP_ONDATASETCHANGED
#define DISPID_IHTMLELEMENT_ONDATAAVAILABLE      DISPID_EVPROP_ONDATAAVAILABLE
#define DISPID_IHTMLELEMENT_ONDATASETCOMPLETE    DISPID_EVPROP_ONDATASETCOMPLETE
#define DISPID_IHTMLELEMENT_ONFILTERCHANGE       DISPID_EVPROP_ONFILTER

/* IHTMLelement2 */
#define DISPID_IHTMLELEMENT2_SCOPENAME              DISPID_ELEMENT+39
#define DISPID_IHTMLELEMENT2_SETCAPTURE             DISPID_ELEMENT+40
#define DISPID_IHTMLELEMENT2_RELEASECAPTURE         DISPID_ELEMENT+41
#define DISPID_IHTMLELEMENT2_ONLOSECAPTURE          DISPID_EVPROP_ONLOSECAPTURE
#define DISPID_IHTMLELEMENT2_COMPONENTFROMPOINT     DISPID_ELEMENT+42
#define DISPID_IHTMLELEMENT2_DOSCROLL               DISPID_ELEMENT+43
#define DISPID_IHTMLELEMENT2_ONSCROLL               DISPID_EVPROP_ONSCROLL
#define DISPID_IHTMLELEMENT2_ONDRAG                 DISPID_EVPROP_ONDRAG
#define DISPID_IHTMLELEMENT2_ONDRAGEND              DISPID_EVPROP_ONDRAGEND
#define DISPID_IHTMLELEMENT2_ONDRAGENTER            DISPID_EVPROP_ONDRAGENTER
#define DISPID_IHTMLELEMENT2_ONDRAGOVER             DISPID_EVPROP_ONDRAGOVER
#define DISPID_IHTMLELEMENT2_ONDRAGLEAVE            DISPID_EVPROP_ONDRAGLEAVE
#define DISPID_IHTMLELEMENT2_ONDROP                 DISPID_EVPROP_ONDROP
#define DISPID_IHTMLELEMENT2_ONBEFORECUT            DISPID_EVPROP_ONBEFORECUT
#define DISPID_IHTMLELEMENT2_ONCUT                  DISPID_EVPROP_ONCUT
#define DISPID_IHTMLELEMENT2_ONBEFORECOPY           DISPID_EVPROP_ONBEFORECOPY
#define DISPID_IHTMLELEMENT2_ONCOPY                 DISPID_EVPROP_ONCOPY
#define DISPID_IHTMLELEMENT2_ONBEFOREPASTE          DISPID_EVPROP_ONBEFOREPASTE
#define DISPID_IHTMLELEMENT2_ONPASTE                DISPID_EVPROP_ONPASTE
#define DISPID_IHTMLELEMENT2_CURRENTSTYLE           DISPID_ELEMENT+7
#define DISPID_IHTMLELEMENT2_ONPROPERTYCHANGE       DISPID_EVPROP_ONPROPERTYCHANGE
#define DISPID_IHTMLELEMENT2_GETCLIENTRECTS         DISPID_ELEMENT+44
#define DISPID_IHTMLELEMENT2_GETBOUNDINGCLIENTRECT  DISPID_ELEMENT+45
#define DISPID_IHTMLELEMENT2_SETEXPRESSION          DISPID_HTMLOBJECT+4
#define DISPID_IHTMLELEMENT2_GETEXPRESSION          DISPID_HTMLOBJECT+5
#define DISPID_IHTMLELEMENT2_REMOVEEXPRESSION       DISPID_HTMLOBJECT+6
#define DISPID_IHTMLELEMENT2_TABINDEX               STDPROPID_XOBJ_TABINDEX
#define DISPID_IHTMLELEMENT2_FOCUS                  DISPID_SITE
#define DISPID_IHTMLELEMENT2_ACCESSKEY              DISPID_SITE+5
#define DISPID_IHTMLELEMENT2_ONBLUR                 DISPID_EVPROP_ONBLUR
#define DISPID_IHTMLELEMENT2_ONFOCUS                DISPID_EVPROP_ONFOCUS
#define DISPID_IHTMLELEMENT2_ONRESIZE               DISPID_EVPROP_ONRESIZE
#define DISPID_IHTMLELEMENT2_BLUR                   DISPID_SITE+2
#define DISPID_IHTMLELEMENT2_ADDFILTER              DISPID_SITE+17
#define DISPID_IHTMLELEMENT2_REMOVEFILTER           DISPID_SITE+18
#define DISPID_IHTMLELEMENT2_CLIENTHEIGHT           DISPID_SITE+19
#define DISPID_IHTMLELEMENT2_CLIENTWIDTH            DISPID_SITE+20
#define DISPID_IHTMLELEMENT2_CLIENTTOP              DISPID_SITE+21
#define DISPID_IHTMLELEMENT2_CLIENTLEFT             DISPID_SITE+22
#define DISPID_IHTMLELEMENT2_ATTACHEVENT            DISPID_HTMLOBJECT+7
#define DISPID_IHTMLELEMENT2_DETACHEVENT            DISPID_HTMLOBJECT+8
#define DISPID_IHTMLELEMENT2_READYSTATE             DISPID_A_READYSTATE
#define DISPID_IHTMLELEMENT2_ONREADYSTATECHANGE     DISPID_EVPROP_ONREADYSTATECHANGE
#define DISPID_IHTMLELEMENT2_ONROWSDELETE           DISPID_EVPROP_ONROWSDELETE
#define DISPID_IHTMLELEMENT2_ONROWSINSERTED         DISPID_EVPROP_ONROWSINSERTED
#define DISPID_IHTMLELEMENT2_ONCELLCHANGE           DISPID_EVPROP_ONCELLCHANGE
#define DISPID_IHTMLELEMENT2_DIR                    DISPID_A_DIR
#define DISPID_IHTMLELEMENT2_CREATECONTROLRANGE     DISPID_ELEMENT+56
#define DISPID_IHTMLELEMENT2_SCROLLHEIGHT           DISPID_ELEMENT+57
#define DISPID_IHTMLELEMENT2_SCROLLWIDTH            DISPID_ELEMENT+58
#define DISPID_IHTMLELEMENT2_SCROLLTOP              DISPID_ELEMENT+59
#define DISPID_IHTMLELEMENT2_SCROLLLEFT             DISPID_ELEMENT+60
#define DISPID_IHTMLELEMENT2_CLEARATTRIBUTES        DISPID_ELEMENT+62
#define DISPID_IHTMLELEMENT2_MERGEATTRIBUTES        DISPID_ELEMENT+63
#define DISPID_IHTMLELEMENT2_ONCONTEXTMENU          DISPID_EVPROP_ONCONTEXTMENU
#define DISPID_IHTMLELEMENT2_INSERTADJACENTELEMENT  DISPID_ELEMENT+69
#define DISPID_IHTMLELEMENT2_APPLYELEMENT           DISPID_ELEMENT+65
#define DISPID_IHTMLELEMENT2_GETADJACENTTEXT        DISPID_ELEMENT+70
#define DISPID_IHTMLELEMENT2_REPLACEADJACENTTEXT    DISPID_ELEMENT+71
#define DISPID_IHTMLELEMENT2_CANHAVECHILDREN        DISPID_ELEMENT+72
#define DISPID_IHTMLELEMENT2_ADDBEHAVIOR            DISPID_ELEMENT+80
#define DISPID_IHTMLELEMENT2_REMOVEBEHAVIOR         DISPID_ELEMENT+81
#define DISPID_IHTMLELEMENT2_RUNTIMESTYLE           DISPID_ELEMENT+64
#define DISPID_IHTMLELEMENT2_BEHAVIORURNS           DISPID_ELEMENT+82
#define DISPID_IHTMLELEMENT2_TAGURN                 DISPID_ELEMENT+83
#define DISPID_IHTMLELEMENT2_ONBEFOREEDITFOCUS      DISPID_EVPROP_ONBEFOREEDITFOCUS
#define DISPID_IHTMLELEMENT2_READYSTATEVALUE        DISPID_ELEMENT+84
#define DISPID_IHTMLELEMENT2_GETELEMENTSBYTAGNAME   DISPID_ELEMENT+85

/* IHTMLStyle */
#define DISPID_IHTMLSTYLE_PIXELTOP                    DISPID_STYLE
#define DISPID_IHTMLSTYLE_PIXELLEFT                   (DISPID_STYLE+1)
#define DISPID_IHTMLSTYLE_PIXELWIDTH                  (DISPID_STYLE+2)
#define DISPID_IHTMLSTYLE_PIXELHEIGHT                 (DISPID_STYLE+3)
#define DISPID_IHTMLSTYLE_POSTOP                      (DISPID_STYLE+4)
#define DISPID_IHTMLSTYLE_POSLEFT                     (DISPID_STYLE+5)
#define DISPID_IHTMLSTYLE_POSWIDTH                    (DISPID_STYLE+6)
#define DISPID_IHTMLSTYLE_POSHEIGHT                   (DISPID_STYLE+7)
#define DISPID_IHTMLSTYLE_TOSTRING                    (DISPID_STYLE+8)
#define DISPID_IHTMLSTYLE_SETATTRIBUTE                (DISPID_HTMLOBJECT+1)
#define DISPID_IHTMLSTYLE_GETATTRIBUTE                (DISPID_HTMLOBJECT+2)
#define DISPID_IHTMLSTYLE_REMOVEATTRIBUTE             (DISPID_HTMLOBJECT+3)
#define DISPID_IHTMLSTYLE_FONTFAMILY                  DISPID_A_FONTFACE
#define DISPID_IHTMLSTYLE_FONTSTYLE                   DISPID_A_FONTSTYLE
#define DISPID_IHTMLSTYLE_FONTVARIANT                 DISPID_A_FONTVARIANT
#define DISPID_IHTMLSTYLE_FONTWEIGHT                  DISPID_A_FONTWEIGHT
#define DISPID_IHTMLSTYLE_FONTSIZE                    DISPID_A_FONTSIZE
#define DISPID_IHTMLSTYLE_FONT                        DISPID_A_FONT
#define DISPID_IHTMLSTYLE_COLOR                       DISPID_A_COLOR
#define DISPID_IHTMLSTYLE_BACKGROUND                  DISPID_A_BACKGROUND
#define DISPID_IHTMLSTYLE_BACKGROUNDIMAGE             DISPID_A_BACKGROUNDIMAGE
#define DISPID_IHTMLSTYLE_BACKGROUNDREPEAT            DISPID_A_BACKGROUNDREPEAT
#define DISPID_IHTMLSTYLE_BACKGROUNDATTACHMENT        DISPID_A_BACKGROUNDATTACHMENT
#define DISPID_IHTMLSTYLE_BACKGROUNDPOSITION          DISPID_A_BACKGROUNDPOSITION
#define DISPID_IHTMLSTYLE_BACKGROUNDPOSITIONX         DISPID_A_BACKGROUNDPOSX
#define DISPID_IHTMLSTYLE_BACKGROUNDPOSITIONY         DISPID_A_BACKGROUNDPOSY
#define DISPID_IHTMLSTYLE_WORDSPACING                 DISPID_A_WORDSPACING
#define DISPID_IHTMLSTYLE_LETTERSPACING               DISPID_A_LETTERSPACING
#define DISPID_IHTMLSTYLE_TEXTDECORATION              DISPID_A_TEXTDECORATION
#define DISPID_IHTMLSTYLE_TEXTDECORATIONNONE          DISPID_A_TEXTDECORATIONNONE
#define DISPID_IHTMLSTYLE_TEXTDECORATIONUNDERLINE     DISPID_A_TEXTDECORATIONUNDERLINE
#define DISPID_IHTMLSTYLE_TEXTDECORATIONOVERLINE      DISPID_A_TEXTDECORATIONOVERLINE
#define DISPID_IHTMLSTYLE_TEXTDECORATIONLINETHROUGH   DISPID_A_TEXTDECORATIONLINETHROUGH
#define DISPID_IHTMLSTYLE_TEXTDECORATIONBLINK         DISPID_A_TEXTDECORATIONBLINK
#define DISPID_IHTMLSTYLE_VERTICALALIGN               DISPID_A_VERTICALALIGN
#define DISPID_IHTMLSTYLE_TEXTTRANSFORM               DISPID_A_TEXTTRANSFORM
#define DISPID_IHTMLSTYLE_TEXTINDENT                  DISPID_A_TEXTINDENT
#define DISPID_IHTMLSTYLE_LINEHEIGHT                  DISPID_A_LINEHEIGHT
#define DISPID_IHTMLSTYLE_MARGINTOP                   DISPID_A_MARGINTOP
#define DISPID_IHTMLSTYLE_MARGINRIGHT                 DISPID_A_MARGINRIGHT
#define DISPID_IHTMLSTYLE_MARGINBOTTOM                DISPID_A_MARGINBOTTOM
#define DISPID_IHTMLSTYLE_MARGINLEFT                  DISPID_A_MARGINLEFT
#define DISPID_IHTMLSTYLE_MARGIN                      DISPID_A_MARGIN
#define DISPID_IHTMLSTYLE_PADDINGTOP                  DISPID_A_PADDINGTOP
#define DISPID_IHTMLSTYLE_PADDINGRIGHT                DISPID_A_PADDINGRIGHT
#define DISPID_IHTMLSTYLE_PADDINGBOTTOM               DISPID_A_PADDINGBOTTOM
#define DISPID_IHTMLSTYLE_PADDINGLEFT                 DISPID_A_PADDINGLEFT
#define DISPID_IHTMLSTYLE_PADDING                     DISPID_A_PADDING
#define DISPID_IHTMLSTYLE_BORDER                      DISPID_A_BORDER
#define DISPID_IHTMLSTYLE_BORDERTOP                   DISPID_A_BORDERTOP
#define DISPID_IHTMLSTYLE_BORDERRIGHT                 DISPID_A_BORDERRIGHT
#define DISPID_IHTMLSTYLE_BORDERBOTTOM                DISPID_A_BORDERBOTTOM
#define DISPID_IHTMLSTYLE_BORDERLEFT                  DISPID_A_BORDERLEFT
#define DISPID_IHTMLSTYLE_BORDERCOLOR                 DISPID_A_BORDERCOLOR
#define DISPID_IHTMLSTYLE_BORDERTOPCOLOR              DISPID_A_BORDERTOPCOLOR
#define DISPID_IHTMLSTYLE_BORDERRIGHTCOLOR            DISPID_A_BORDERRIGHTCOLOR
#define DISPID_IHTMLSTYLE_BORDERBOTTOMCOLOR           DISPID_A_BORDERBOTTOMCOLOR
#define DISPID_IHTMLSTYLE_BORDERLEFTCOLOR             DISPID_A_BORDERLEFTCOLOR
#define DISPID_IHTMLSTYLE_BORDERWIDTH                 DISPID_A_BORDERWIDTH
#define DISPID_IHTMLSTYLE_BORDERTOPWIDTH              DISPID_A_BORDERTOPWIDTH
#define DISPID_IHTMLSTYLE_BORDERRIGHTWIDTH            DISPID_A_BORDERRIGHTWIDTH
#define DISPID_IHTMLSTYLE_BORDERBOTTOMWIDTH           DISPID_A_BORDERBOTTOMWIDTH
#define DISPID_IHTMLSTYLE_BORDERLEFTWIDTH             DISPID_A_BORDERLEFTWIDTH
#define DISPID_IHTMLSTYLE_BORDERSTYLE                 DISPID_A_BORDERSTYLE
#define DISPID_IHTMLSTYLE_BORDERTOPSTYLE              DISPID_A_BORDERTOPSTYLE
#define DISPID_IHTMLSTYLE_BORDERRIGHTSTYLE            DISPID_A_BORDERRIGHTSTYLE
#define DISPID_IHTMLSTYLE_BORDERBOTTOMSTYLE           DISPID_A_BORDERBOTTOMSTYLE
#define DISPID_IHTMLSTYLE_BORDERLEFTSTYLE             DISPID_A_BORDERLEFTSTYLE
#define DISPID_IHTMLSTYLE_STYLEFLOAT                  DISPID_A_FLOAT
#define DISPID_IHTMLSTYLE_CLEAR                       DISPID_A_CLEAR
#define DISPID_IHTMLSTYLE_DISPLAY                     DISPID_A_DISPLAY
#define DISPID_IHTMLSTYLE_VISIBILITY                  DISPID_A_VISIBILITY
#define DISPID_IHTMLSTYLE_LISTSTYLETYPE               DISPID_A_LISTSTYLETYPE
#define DISPID_IHTMLSTYLE_LISTSTYLEPOSITION           DISPID_A_LISTSTYLEPOSITION
#define DISPID_IHTMLSTYLE_LISTSTYLEIMAGE              DISPID_A_LISTSTYLEIMAGE
#define DISPID_IHTMLSTYLE_LISTSTYLE                   DISPID_A_LISTSTYLE
#define DISPID_IHTMLSTYLE_WHITESPACE                  DISPID_A_WHITESPACE
#define DISPID_IHTMLSTYLE_POSITION                    DISPID_A_POSITION
#define DISPID_IHTMLSTYLE_ZINDEX                      DISPID_A_ZINDEX
#define DISPID_IHTMLSTYLE_OVERFLOW                    DISPID_A_OVERFLOW
#define DISPID_IHTMLSTYLE_PAGEBREAKBEFORE             DISPID_A_PAGEBREAKBEFORE
#define DISPID_IHTMLSTYLE_PAGEBREAKAFTER              DISPID_A_PAGEBREAKAFTER
#define DISPID_IHTMLSTYLE_CSSTEXT                     DISPID_A_STYLETEXT
#define DISPID_IHTMLSTYLE_CURSOR                      DISPID_A_CURSOR
#define DISPID_IHTMLSTYLE_CLIP                        DISPID_A_CLIP
#define DISPID_IHTMLSTYLE_FILTER                      DISPID_A_FILTER
#define DISPID_IHTMLSTYLE_WIDTH                       STDPROPID_XOBJ_WIDTH
#define DISPID_IHTMLSTYLE_HEIGHT                      STDPROPID_XOBJ_HEIGHT
#define DISPID_IHTMLSTYLE_TOP                         STDPROPID_XOBJ_TOP
#define DISPID_IHTMLSTYLE_LEFT                        STDPROPID_XOBJ_LEFT
#define DISPID_IHTMLSTYLE_TEXTALIGN                   STDPROPID_XOBJ_BLOCKALIGN
#define DISPID_IHTMLSTYLE_BACKGROUNDCOLOR             DISPID_BACKCOLOR

/* IHTMLFiltersCollection */
#define DISPID_IHTMLFILTERSCOLLECTION_LENGTH     (DISPID_FILTERS+1)
#define DISPID_IHTMLFILTERSCOLLECTION__NEWENUM   DISPID_NEWENUM
#define DISPID_IHTMLFILTERSCOLLECTION_ITEM       DISPID_VALUE

/* IHTMLSelectionObject */
#define DISPID_IHTMLSELECTIONOBJECT_CREATERANGE   (DISPID_SELECTOBJ+1)
#define DISPID_IHTMLSELECTIONOBJECT_EMPTY         (DISPID_SELECTOBJ+2)
#define DISPID_IHTMLSELECTIONOBJECT_CLEAR         (DISPID_SELECTOBJ+3)
#define DISPID_IHTMLSELECTIONOBJECT_TYPE          (DISPID_SELECTOBJ+4)

/* IHTMLFramesCollection2 */
#define DISPID_IHTMLFRAMESCOLLECTION2_ITEM     0
#define DISPID_IHTMLFRAMESCOLLECTION2_LENGTH   1001

/* IHTMLLocation */
#define DISPID_IHTMLLOCATION_HOST       (DISPID_LOCATION+1)
#define DISPID_IHTMLLOCATION_HOSTNAME   (DISPID_LOCATION+2)
#define DISPID_IHTMLLOCATION_PORT       (DISPID_LOCATION+3)
#define DISPID_IHTMLLOCATION_PATHNAME   (DISPID_LOCATION+4)
#define DISPID_IHTMLLOCATION_SEARCH     (DISPID_LOCATION+5)
#define DISPID_IHTMLLOCATION_HASH       (DISPID_LOCATION+6)
#define DISPID_IHTMLLOCATION_RELOAD     (DISPID_LOCATION+7)
#define DISPID_IHTMLLOCATION_REPLACE    (DISPID_LOCATION+8)
#define DISPID_IHTMLLOCATION_ASSIGN     (DISPID_LOCATION+9)
#define DISPID_IHTMLLOCATION_TOSTRING   (DISPID_LOCATION+10)
#define DISPID_IHTMLLOCATION_HREF       DISPID_VALUE
#define DISPID_IHTMLLOCATION_PROTOCOL   DISPID_LOCATION

/* IHTMLWindow2 */
#define DISPID_IHTMLWINDOW2_HISTORY              2
#define DISPID_IHTMLWINDOW2_CLOSE                3
#define DISPID_IHTMLWINDOW2_OPENER               4
#define DISPID_IHTMLWINDOW2_NAVIGATOR            5
#define DISPID_IHTMLWINDOW2_MOVETO               6
#define DISPID_IHTMLWINDOW2_MOVEBY               7
#define DISPID_IHTMLWINDOW2_RESIZETO             9
#define DISPID_IHTMLWINDOW2_RESIZEBY             8
#define DISPID_IHTMLWINDOW2_NAME                 11
#define DISPID_IHTMLWINDOW2_PARENT               12
#define DISPID_IHTMLWINDOW2_OPEN                 13
#define DISPID_IHTMLWINDOW2_LOCATION             14
#define DISPID_IHTMLWINDOW2_SELF                 20
#define DISPID_IHTMLWINDOW2_TOP                  21
#define DISPID_IHTMLWINDOW2_WINDOW               22
#define DISPID_IHTMLWINDOW2_CLOSED               23
#define DISPID_IHTMLWINDOW2_NAVIGATE             25
#define DISPID_IHTMLWINDOW2_FRAMES               1100
#define DISPID_IHTMLWINDOW2_DEFAULTSTATUS        1101
#define DISPID_IHTMLWINDOW2_STATUS               1102
#define DISPID_IHTMLWINDOW2_SETTIMEOUT           1103
#define DISPID_IHTMLWINDOW2_CLEARTIMEOUT         1104
#define DISPID_IHTMLWINDOW2_ALERT                1105
#define DISPID_IHTMLWINDOW2_CONFIRM              1110
#define DISPID_IHTMLWINDOW2_PROMPT               1111
#define DISPID_IHTMLWINDOW2_IMAGE                1125
#define DISPID_IHTMLWINDOW2_DOCUMENT             1151
#define DISPID_IHTMLWINDOW2_EVENT                1152
#define DISPID_IHTMLWINDOW2__NEWENUM             1153
#define DISPID_IHTMLWINDOW2_SHOWMODALDIALOG      1154
#define DISPID_IHTMLWINDOW2_SHOWHELP             1155
#define DISPID_IHTMLWINDOW2_SCREEN               1156
#define DISPID_IHTMLWINDOW2_OPTION               1157
#define DISPID_IHTMLWINDOW2_FOCUS                1158
#define DISPID_IHTMLWINDOW2_BLUR                 1159
#define DISPID_IHTMLWINDOW2_SCROLL               1160
#define DISPID_IHTMLWINDOW2_CLIENTINFORMATION    1161
#define DISPID_IHTMLWINDOW2_SETINTERVAL          1162
#define DISPID_IHTMLWINDOW2_CLEARINTERVAL        1163
#define DISPID_IHTMLWINDOW2_OFFSCREENBUFFERING   1164
#define DISPID_IHTMLWINDOW2_EXECSCRIPT           1165
#define DISPID_IHTMLWINDOW2_TOSTRING             1166
#define DISPID_IHTMLWINDOW2_SCROLLBY             1167
#define DISPID_IHTMLWINDOW2_SCROLLTO             1168
#define DISPID_IHTMLWINDOW2_EXTERNAL             1169
#define DISPID_IHTMLWINDOW2_ONFOCUS              DISPID_EVPROP_ONFOCUS
#define DISPID_IHTMLWINDOW2_ONBLUR               DISPID_EVPROP_ONBLUR
#define DISPID_IHTMLWINDOW2_ONLOAD               DISPID_EVPROP_ONLOAD
#define DISPID_IHTMLWINDOW2_ONBEFOREUNLOAD       DISPID_EVPROP_ONBEFOREUNLOAD
#define DISPID_IHTMLWINDOW2_ONUNLOAD             DISPID_EVPROP_ONUNLOAD
#define DISPID_IHTMLWINDOW2_ONHELP               DISPID_EVPROP_ONHELP
#define DISPID_IHTMLWINDOW2_ONERROR              DISPID_EVPROP_ONERROR
#define DISPID_IHTMLWINDOW2_ONRESIZE             DISPID_EVPROP_ONRESIZE
#define DISPID_IHTMLWINDOW2_ONSCROLL             DISPID_EVPROP_ONSCROLL

/* IHTMLImageElementFactory */
#define DISPID_IHTMLIMAGEELEMENTFACTORY_CREATE                    DISPID_VALUE

/* IHTMLImgElement */
#define DISPID_IHTMLIMGELEMENT_BORDER             (DISPID_IMGBASE+4)
#define DISPID_IHTMLIMGELEMENT_VSPACE             (DISPID_IMGBASE+5)
#define DISPID_IHTMLIMGELEMENT_HSPACE             (DISPID_IMGBASE+6)
#define DISPID_IHTMLIMGELEMENT_ALT                (DISPID_IMGBASE+2)
#define DISPID_IHTMLIMGELEMENT_SRC                (DISPID_IMGBASE+3)
#define DISPID_IHTMLIMGELEMENT_LOWSRC             (DISPID_IMGBASE+7)
#define DISPID_IHTMLIMGELEMENT_VRML               (DISPID_IMGBASE+8)
#define DISPID_IHTMLIMGELEMENT_DYNSRC             (DISPID_IMGBASE+9)
#define DISPID_IHTMLIMGELEMENT_READYSTATE         (DISPID_IMGBASE+12)
#define DISPID_IHTMLIMGELEMENT_COMPLETE           (DISPID_IMGBASE+10)
#define DISPID_IHTMLIMGELEMENT_LOOP               (DISPID_IMGBASE+11)
#define DISPID_IHTMLIMGELEMENT_ISMAP              (DISPID_IMG+2)
#define DISPID_IHTMLIMGELEMENT_USEMAP             (DISPID_IMG+8)
#define DISPID_IHTMLIMGELEMENT_MIMETYPE           (DISPID_IMG+10)
#define DISPID_IHTMLIMGELEMENT_FILESIZE           (DISPID_IMG+11)
#define DISPID_IHTMLIMGELEMENT_FILECREATEDDATE    (DISPID_IMG+12)
#define DISPID_IHTMLIMGELEMENT_FILEMODIFIEDDATE   (DISPID_IMG+13)
#define DISPID_IHTMLIMGELEMENT_FILEUPDATEDDATE    (DISPID_IMG+14)
#define DISPID_IHTMLIMGELEMENT_PROTOCOL           (DISPID_IMG+15)
#define DISPID_IHTMLIMGELEMENT_HREF               (DISPID_IMG+16)
#define DISPID_IHTMLIMGELEMENT_NAMEPROP           (DISPID_IMG+17)
#define DISPID_IHTMLIMGELEMENT_ALIGN              STDPROPID_XOBJ_CONTROLALIGN
#define DISPID_IHTMLIMGELEMENT_ONLOAD             DISPID_EVPROP_ONLOAD
#define DISPID_IHTMLIMGELEMENT_ONERROR            DISPID_EVPROP_ONERROR
#define DISPID_IHTMLIMGELEMENT_ONABORT            DISPID_EVPROP_ONABORT
#define DISPID_IHTMLIMGELEMENT_NAME               STDPROPID_XOBJ_NAME
#define DISPID_IHTMLIMGELEMENT_WIDTH              STDPROPID_XOBJ_WIDTH
#define DISPID_IHTMLIMGELEMENT_HEIGHT             STDPROPID_XOBJ_HEIGHT
#define DISPID_IHTMLIMGELEMENT_START              DISPID_IMGBASE+13

/* IOmHistory */
#define DISPID_IOMHISTORY_LENGTH    DISPID_HISTORY
#define DISPID_IOMHISTORY_BACK      (DISPID_HISTORY+1)
#define DISPID_IOMHISTORY_FORWARD   (DISPID_HISTORY+2)
#define DISPID_IOMHISTORY_GO        (DISPID_HISTORY+3)

/* IOmNavigator */
#define DISPID_IOMNAVIGATOR_APPCODENAME       DISPID_NAVIGATOR
#define DISPID_IOMNAVIGATOR_APPNAME           (DISPID_NAVIGATOR+1)
#define DISPID_IOMNAVIGATOR_APPVERSION        (DISPID_NAVIGATOR+2)
#define DISPID_IOMNAVIGATOR_USERAGENT         (DISPID_NAVIGATOR+3)
#define DISPID_IOMNAVIGATOR_JAVAENABLED       (DISPID_NAVIGATOR+4)
#define DISPID_IOMNAVIGATOR_TAINTENABLED      (DISPID_NAVIGATOR+5)
#define DISPID_IOMNAVIGATOR_MIMETYPES         (DISPID_NAVIGATOR+6)
#define DISPID_IOMNAVIGATOR_PLUGINS           (DISPID_NAVIGATOR+7)
#define DISPID_IOMNAVIGATOR_COOKIEENABLED     (DISPID_NAVIGATOR+8)
#define DISPID_IOMNAVIGATOR_OPSPROFILE        (DISPID_NAVIGATOR+9)
#define DISPID_IOMNAVIGATOR_TOSTRING          (DISPID_NAVIGATOR+10)
#define DISPID_IOMNAVIGATOR_CPUCLASS          (DISPID_NAVIGATOR+11)
#define DISPID_IOMNAVIGATOR_SYSTEMLANGUAGE    (DISPID_NAVIGATOR+12)
#define DISPID_IOMNAVIGATOR_BROWSERLANGUAGE   (DISPID_NAVIGATOR+13)
#define DISPID_IOMNAVIGATOR_USERLANGUAGE      (DISPID_NAVIGATOR+14)
#define DISPID_IOMNAVIGATOR_PLATFORM          (DISPID_NAVIGATOR+15)
#define DISPID_IOMNAVIGATOR_APPMINORVERSION   (DISPID_NAVIGATOR+16)
#define DISPID_IOMNAVIGATOR_CONNECTIONSPEED   (DISPID_NAVIGATOR+17)
#define DISPID_IOMNAVIGATOR_ONLINE            (DISPID_NAVIGATOR+18)
#define DISPID_IOMNAVIGATOR_USERPROFILE       (DISPID_NAVIGATOR+19)

/* IHTMLMimeTypesCollection */
#define DISPID_IHTMLMIMETYPESCOLLECTION_LENGTH   1

/* IHTMLPluginsCollection */
#define DISPID_IHTMLPLUGINSCOLLECTION_LENGTH    1
#define DISPID_IHTMLPLUGINSCOLLECTION_REFRESH   2

/* IHTMLOpsProfile */
#define DISPID_IHTMLOPSPROFILE_ADDREQUEST       1
#define DISPID_IHTMLOPSPROFILE_CLEARREQUEST     2
#define DISPID_IHTMLOPSPROFILE_DOREQUEST        3
#define DISPID_IHTMLOPSPROFILE_GETATTRIBUTE     4
#define DISPID_IHTMLOPSPROFILE_SETATTRIBUTE     5
#define DISPID_IHTMLOPSPROFILE_COMMITCHANGES    6
#define DISPID_IHTMLOPSPROFILE_ADDREADREQUEST   7
#define DISPID_IHTMLOPSPROFILE_DOREADREQUEST    8
#define DISPID_IHTMLOPSPROFILE_DOWRITEREQUEST   9

/* IHTMLEventObj */
#define DISPID_IHTMLEVENTOBJ_SRCELEMENT     (DISPID_EVENTOBJ+1)
#define DISPID_IHTMLEVENTOBJ_ALTKEY         (DISPID_EVENTOBJ+2)
#define DISPID_IHTMLEVENTOBJ_CTRLKEY        (DISPID_EVENTOBJ+3)
#define DISPID_IHTMLEVENTOBJ_SHIFTKEY       (DISPID_EVENTOBJ+4)
#define DISPID_IHTMLEVENTOBJ_X              (DISPID_EVENTOBJ+5)
#define DISPID_IHTMLEVENTOBJ_Y              (DISPID_EVENTOBJ+6)
#define DISPID_IHTMLEVENTOBJ_RETURNVALUE    (DISPID_EVENTOBJ+7)
#define DISPID_IHTMLEVENTOBJ_CANCELBUBBLE   (DISPID_EVENTOBJ+8)
#define DISPID_IHTMLEVENTOBJ_FROMELEMENT    (DISPID_EVENTOBJ+9)
#define DISPID_IHTMLEVENTOBJ_TOELEMENT      (DISPID_EVENTOBJ+10)
#define DISPID_IHTMLEVENTOBJ_KEYCODE        (DISPID_EVENTOBJ+11)
#define DISPID_IHTMLEVENTOBJ_BUTTON         (DISPID_EVENTOBJ+12)
#define DISPID_IHTMLEVENTOBJ_TYPE           (DISPID_EVENTOBJ+13)
#define DISPID_IHTMLEVENTOBJ_QUALIFIER      (DISPID_EVENTOBJ+14)
#define DISPID_IHTMLEVENTOBJ_REASON         (DISPID_EVENTOBJ+15)
#define DISPID_IHTMLEVENTOBJ_CLIENTX        (DISPID_EVENTOBJ+20)
#define DISPID_IHTMLEVENTOBJ_CLIENTY        (DISPID_EVENTOBJ+21)
#define DISPID_IHTMLEVENTOBJ_OFFSETX        (DISPID_EVENTOBJ+22)
#define DISPID_IHTMLEVENTOBJ_OFFSETY        (DISPID_EVENTOBJ+23)
#define DISPID_IHTMLEVENTOBJ_SCREENX        (DISPID_EVENTOBJ+24)
#define DISPID_IHTMLEVENTOBJ_SCREENY        (DISPID_EVENTOBJ+25)
#define DISPID_IHTMLEVENTOBJ_SRCFILTER      (DISPID_EVENTOBJ+26)

/* IHTMLScreen */
#define DISPID_IHTMLSCREEN_COLORDEPTH             (DISPID_SCREEN+1)
#define DISPID_IHTMLSCREEN_BUFFERDEPTH            (DISPID_SCREEN+2)
#define DISPID_IHTMLSCREEN_WIDTH                  (DISPID_SCREEN+3)
#define DISPID_IHTMLSCREEN_HEIGHT                 (DISPID_SCREEN+4)
#define DISPID_IHTMLSCREEN_UPDATEINTERVAL         (DISPID_SCREEN+5)
#define DISPID_IHTMLSCREEN_AVAILHEIGHT            (DISPID_SCREEN+6)
#define DISPID_IHTMLSCREEN_AVAILWIDTH             (DISPID_SCREEN+7)
#define DISPID_IHTMLSCREEN_FONTSMOOTHINGENABLED   (DISPID_SCREEN+8)

/* IHTMLOptionElementFactory */
#define DISPID_IHTMLOPTIONELEMENTFACTORY_CREATE   DISPID_VALUE

/* IHTMLOptionElement */
#define DISPID_IHTMLOPTIONELEMENT_SELECTED          (DISPID_OPTION+1)
#define DISPID_IHTMLOPTIONELEMENT_VALUE             (DISPID_OPTION+2)
#define DISPID_IHTMLOPTIONELEMENT_DEFAULTSELECTED   (DISPID_OPTION+3)
#define DISPID_IHTMLOPTIONELEMENT_INDEX             (DISPID_OPTION+5)
#define DISPID_IHTMLOPTIONELEMENT_TEXT              (DISPID_OPTION+4)
#define DISPID_IHTMLOPTIONELEMENT_FORM              (DISPID_OPTION+6)

/* IHTMLFormElement */
#define DISPID_IHTMLFORMELEMENT_ACTION     (DISPID_FORM+1)
#define DISPID_IHTMLFORMELEMENT_DIR        (DISPID_FORM+2)
#define DISPID_IHTMLFORMELEMENT_ENCODING   (DISPID_FORM+3)
#define DISPID_IHTMLFORMELEMENT_METHOD     (DISPID_FORM+4)
#define DISPID_IHTMLFORMELEMENT_ELEMENTS   (DISPID_FORM+5)
#define DISPID_IHTMLFORMELEMENT_TARGET     (DISPID_FORM+6)
#define DISPID_IHTMLFORMELEMENT_SUBMIT     (DISPID_FORM+9)
#define DISPID_IHTMLFORMELEMENT_RESET      (DISPID_FORM+10)
#define DISPID_IHTMLFORMELEMENT_TAGS       (DISPID_COLLECTION+2)
#define DISPID_IHTMLFORMELEMENT_NAME       STDPROPID_XOBJ_NAME
#define DISPID_IHTMLFORMELEMENT_ONSUBMIT   DISPID_EVPROP_ONSUBMIT
#define DISPID_IHTMLFORMELEMENT_ONRESET    DISPID_EVPROP_ONRESET
#define DISPID_IHTMLFORMELEMENT_LENGTH     DISPID_COLLECTION
#define DISPID_IHTMLFORMELEMENT__NEWENUM   DISPID_NEWENUM
#define DISPID_IHTMLFORMELEMENT_ITEM       DISPID_VALUE

/* IHTMLStyleSheetsCollection */
#define DISPID_IHTMLSTYLESHEETSCOLLECTION_LENGTH     (DISPID_STYLESHEETS_COL+1)
#define DISPID_IHTMLSTYLESHEETSCOLLECTION__NEWENUM   DISPID_NEWENUM
#define DISPID_IHTMLSTYLESHEETSCOLLECTION_ITEM       DISPID_VALUE

/* IHTMLStyleSheet */
#define DISPID_IHTMLSTYLESHEET_TITLE              (DISPID_STYLESHEET+1)
#define DISPID_IHTMLSTYLESHEET_PARENTSTYLESHEET   (DISPID_STYLESHEET+2)
#define DISPID_IHTMLSTYLESHEET_OWNINGELEMENT      (DISPID_STYLESHEET+3)
#define DISPID_IHTMLSTYLESHEET_READONLY           (DISPID_STYLESHEET+4)
#define DISPID_IHTMLSTYLESHEET_IMPORTS            (DISPID_STYLESHEET+5)
#define DISPID_IHTMLSTYLESHEET_HREF               (DISPID_STYLESHEET+6)
#define DISPID_IHTMLSTYLESHEET_TYPE               (DISPID_STYLESHEET+7)
#define DISPID_IHTMLSTYLESHEET_ID                 (DISPID_STYLESHEET+8)
#define DISPID_IHTMLSTYLESHEET_ADDIMPORT          (DISPID_STYLESHEET+9)
#define DISPID_IHTMLSTYLESHEET_ADDRULE            (DISPID_STYLESHEET+10)
#define DISPID_IHTMLSTYLESHEET_REMOVEIMPORT       (DISPID_STYLESHEET+11)
#define DISPID_IHTMLSTYLESHEET_REMOVERULE         (DISPID_STYLESHEET+12)
#define DISPID_IHTMLSTYLESHEET_MEDIA              (DISPID_STYLESHEET+13)
#define DISPID_IHTMLSTYLESHEET_CSSTEXT            (DISPID_STYLESHEET+14)
#define DISPID_IHTMLSTYLESHEET_RULES              (DISPID_STYLESHEET+15)
#define DISPID_IHTMLSTYLESHEET_DISABLED           STDPROPID_XOBJ_DISABLED

/* IHTMLStyleSheetRulesCollection */
#define DISPID_IHTMLSTYLESHEETRULESCOLLECTION_LENGTH   (DISPID_STYLERULES_COL+1)
#define DISPID_IHTMLSTYLESHEETRULESCOLLECTION_ITEM     DISPID_VALUE

/* IHTMLStyleSheetRule */
#define DISPID_IHTMLSTYLESHEETRULE_SELECTORTEXT   (DISPID_STYLERULE+1)
#define DISPID_IHTMLSTYLESHEETRULE_READONLY       (DISPID_STYLERULE+2)
#define DISPID_IHTMLSTYLESHEETRULE_STYLE          STDPROPID_XOBJ_STYLE

/* IHTMLRuleStyle */
#define DISPID_IHTMLRULESTYLE_SETATTRIBUTE                (DISPID_HTMLOBJECT+1)
#define DISPID_IHTMLRULESTYLE_GETATTRIBUTE                (DISPID_HTMLOBJECT+2)
#define DISPID_IHTMLRULESTYLE_REMOVEATTRIBUTE             (DISPID_HTMLOBJECT+3)
#define DISPID_IHTMLRULESTYLE_FONTFAMILY                  DISPID_A_FONTFACE
#define DISPID_IHTMLRULESTYLE_FONTSTYLE                   DISPID_A_FONTSTYLE
#define DISPID_IHTMLRULESTYLE_FONTVARIANT                 DISPID_A_FONTVARIANT
#define DISPID_IHTMLRULESTYLE_FONTWEIGHT                  DISPID_A_FONTWEIGHT
#define DISPID_IHTMLRULESTYLE_FONTSIZE                    DISPID_A_FONTSIZE
#define DISPID_IHTMLRULESTYLE_FONT                        DISPID_A_FONT
#define DISPID_IHTMLRULESTYLE_COLOR                       DISPID_A_COLOR
#define DISPID_IHTMLRULESTYLE_BACKGROUND                  DISPID_A_BACKGROUND
#define DISPID_IHTMLRULESTYLE_BACKGROUNDIMAGE             DISPID_A_BACKGROUNDIMAGE
#define DISPID_IHTMLRULESTYLE_BACKGROUNDREPEAT            DISPID_A_BACKGROUNDREPEAT
#define DISPID_IHTMLRULESTYLE_BACKGROUNDATTACHMENT        DISPID_A_BACKGROUNDATTACHMENT
#define DISPID_IHTMLRULESTYLE_BACKGROUNDPOSITION          DISPID_A_BACKGROUNDPOSITION
#define DISPID_IHTMLRULESTYLE_BACKGROUNDPOSITIONX         DISPID_A_BACKGROUNDPOSX
#define DISPID_IHTMLRULESTYLE_BACKGROUNDPOSITIONY         DISPID_A_BACKGROUNDPOSY
#define DISPID_IHTMLRULESTYLE_WORDSPACING                 DISPID_A_WORDSPACING
#define DISPID_IHTMLRULESTYLE_LETTERSPACING               DISPID_A_LETTERSPACING
#define DISPID_IHTMLRULESTYLE_TEXTDECORATION              DISPID_A_TEXTDECORATION
#define DISPID_IHTMLRULESTYLE_TEXTDECORATIONNONE          DISPID_A_TEXTDECORATIONNONE
#define DISPID_IHTMLRULESTYLE_TEXTDECORATIONUNDERLINE     DISPID_A_TEXTDECORATIONUNDERLINE
#define DISPID_IHTMLRULESTYLE_TEXTDECORATIONOVERLINE      DISPID_A_TEXTDECORATIONOVERLINE
#define DISPID_IHTMLRULESTYLE_TEXTDECORATIONLINETHROUGH   DISPID_A_TEXTDECORATIONLINETHROUGH
#define DISPID_IHTMLRULESTYLE_TEXTDECORATIONBLINK         DISPID_A_TEXTDECORATIONBLINK
#define DISPID_IHTMLRULESTYLE_VERTICALALIGN               DISPID_A_VERTICALALIGN
#define DISPID_IHTMLRULESTYLE_TEXTTRANSFORM               DISPID_A_TEXTTRANSFORM
#define DISPID_IHTMLRULESTYLE_TEXTINDENT                  DISPID_A_TEXTINDENT
#define DISPID_IHTMLRULESTYLE_LINEHEIGHT                  DISPID_A_LINEHEIGHT
#define DISPID_IHTMLRULESTYLE_MARGINTOP                   DISPID_A_MARGINTOP
#define DISPID_IHTMLRULESTYLE_MARGINRIGHT                 DISPID_A_MARGINRIGHT
#define DISPID_IHTMLRULESTYLE_MARGINBOTTOM                DISPID_A_MARGINBOTTOM
#define DISPID_IHTMLRULESTYLE_MARGINLEFT                  DISPID_A_MARGINLEFT
#define DISPID_IHTMLRULESTYLE_MARGIN                      DISPID_A_MARGIN
#define DISPID_IHTMLRULESTYLE_PADDINGTOP                  DISPID_A_PADDINGTOP
#define DISPID_IHTMLRULESTYLE_PADDINGRIGHT                DISPID_A_PADDINGRIGHT
#define DISPID_IHTMLRULESTYLE_PADDINGBOTTOM               DISPID_A_PADDINGBOTTOM
#define DISPID_IHTMLRULESTYLE_PADDINGLEFT                 DISPID_A_PADDINGLEFT
#define DISPID_IHTMLRULESTYLE_PADDING                     DISPID_A_PADDING
#define DISPID_IHTMLRULESTYLE_BORDER                      DISPID_A_BORDER
#define DISPID_IHTMLRULESTYLE_BORDERTOP                   DISPID_A_BORDERTOP
#define DISPID_IHTMLRULESTYLE_BORDERRIGHT                 DISPID_A_BORDERRIGHT
#define DISPID_IHTMLRULESTYLE_BORDERBOTTOM                DISPID_A_BORDERBOTTOM
#define DISPID_IHTMLRULESTYLE_BORDERLEFT                  DISPID_A_BORDERLEFT
#define DISPID_IHTMLRULESTYLE_BORDERCOLOR                 DISPID_A_BORDERCOLOR
#define DISPID_IHTMLRULESTYLE_BORDERTOPCOLOR              DISPID_A_BORDERTOPCOLOR
#define DISPID_IHTMLRULESTYLE_BORDERRIGHTCOLOR            DISPID_A_BORDERRIGHTCOLOR
#define DISPID_IHTMLRULESTYLE_BORDERBOTTOMCOLOR           DISPID_A_BORDERBOTTOMCOLOR
#define DISPID_IHTMLRULESTYLE_BORDERLEFTCOLOR             DISPID_A_BORDERLEFTCOLOR
#define DISPID_IHTMLRULESTYLE_BORDERWIDTH                 DISPID_A_BORDERWIDTH
#define DISPID_IHTMLRULESTYLE_BORDERTOPWIDTH              DISPID_A_BORDERTOPWIDTH
#define DISPID_IHTMLRULESTYLE_BORDERRIGHTWIDTH            DISPID_A_BORDERRIGHTWIDTH
#define DISPID_IHTMLRULESTYLE_BORDERBOTTOMWIDTH           DISPID_A_BORDERBOTTOMWIDTH
#define DISPID_IHTMLRULESTYLE_BORDERLEFTWIDTH             DISPID_A_BORDERLEFTWIDTH
#define DISPID_IHTMLRULESTYLE_BORDERSTYLE                 DISPID_A_BORDERSTYLE
#define DISPID_IHTMLRULESTYLE_BORDERTOPSTYLE              DISPID_A_BORDERTOPSTYLE
#define DISPID_IHTMLRULESTYLE_BORDERRIGHTSTYLE            DISPID_A_BORDERRIGHTSTYLE
#define DISPID_IHTMLRULESTYLE_BORDERBOTTOMSTYLE           DISPID_A_BORDERBOTTOMSTYLE
#define DISPID_IHTMLRULESTYLE_BORDERLEFTSTYLE             DISPID_A_BORDERLEFTSTYLE
#define DISPID_IHTMLRULESTYLE_STYLEFLOAT                  DISPID_A_FLOAT
#define DISPID_IHTMLRULESTYLE_CLEAR                       DISPID_A_CLEAR
#define DISPID_IHTMLRULESTYLE_DISPLAY                     DISPID_A_DISPLAY
#define DISPID_IHTMLRULESTYLE_VISIBILITY                  DISPID_A_VISIBILITY
#define DISPID_IHTMLRULESTYLE_LISTSTYLETYPE               DISPID_A_LISTSTYLETYPE
#define DISPID_IHTMLRULESTYLE_LISTSTYLEPOSITION           DISPID_A_LISTSTYLEPOSITION
#define DISPID_IHTMLRULESTYLE_LISTSTYLEIMAGE              DISPID_A_LISTSTYLEIMAGE
#define DISPID_IHTMLRULESTYLE_LISTSTYLE                   DISPID_A_LISTSTYLE
#define DISPID_IHTMLRULESTYLE_WHITESPACE                  DISPID_A_WHITESPACE
#define DISPID_IHTMLRULESTYLE_POSITION                    DISPID_A_POSITION
#define DISPID_IHTMLRULESTYLE_ZINDEX                      DISPID_A_ZINDEX
#define DISPID_IHTMLRULESTYLE_OVERFLOW                    DISPID_A_OVERFLOW
#define DISPID_IHTMLRULESTYLE_PAGEBREAKBEFORE             DISPID_A_PAGEBREAKBEFORE
#define DISPID_IHTMLRULESTYLE_PAGEBREAKAFTER              DISPID_A_PAGEBREAKAFTER
#define DISPID_IHTMLRULESTYLE_CSSTEXT                     DISPID_A_STYLETEXT
#define DISPID_IHTMLRULESTYLE_CURSOR                      DISPID_A_CURSOR
#define DISPID_IHTMLRULESTYLE_CLIP                        DISPID_A_CLIP
#define DISPID_IHTMLRULESTYLE_FILTER                      DISPID_A_FILTER
#define DISPID_IHTMLRULESTYLE_TOP                         STDPROPID_XOBJ_TOP
#define DISPID_IHTMLRULESTYLE_LEFT                        STDPROPID_XOBJ_LEFT
#define DISPID_IHTMLRULESTYLE_WIDTH                       STDPROPID_XOBJ_WIDTH
#define DISPID_IHTMLRULESTYLE_HEIGHT                      STDPROPID_XOBJ_HEIGHT
#define DISPID_IHTMLRULESTYLE_TEXTALIGN                   STDPROPID_XOBJ_BLOCKALIGN
#define DISPID_IHTMLRULESTYLE_BACKGROUNDCOLOR             DISPID_BACKCOLOR

/* IHTMLDOMNode */
#define DISPID_IHTMLDOMNODE_NODETYPE           DISPID_ELEMENT+46
#define DISPID_IHTMLDOMNODE_PARENTNODE         DISPID_ELEMENT+47
#define DISPID_IHTMLDOMNODE_HASCHILDNODES      DISPID_ELEMENT+48
#define DISPID_IHTMLDOMNODE_CHILDNODES         DISPID_ELEMENT+49
#define DISPID_IHTMLDOMNODE_ATTRIBUTES         DISPID_ELEMENT+50
#define DISPID_IHTMLDOMNODE_INSERTBEFORE       DISPID_ELEMENT+51
#define DISPID_IHTMLDOMNODE_REMOVECHILD        DISPID_ELEMENT+52
#define DISPID_IHTMLDOMNODE_REPLACECHILD       DISPID_ELEMENT+53
#define DISPID_IHTMLDOMNODE_CLONENODE          DISPID_ELEMENT+61
#define DISPID_IHTMLDOMNODE_REMOVENODE         DISPID_ELEMENT+66
#define DISPID_IHTMLDOMNODE_SWAPNODE           DISPID_ELEMENT+68
#define DISPID_IHTMLDOMNODE_REPLACENODE        DISPID_ELEMENT+67
#define DISPID_IHTMLDOMNODE_APPENDCHILD        DISPID_ELEMENT+73
#define DISPID_IHTMLDOMNODE_NODENAME           DISPID_ELEMENT+74
#define DISPID_IHTMLDOMNODE_NODEVALUE          DISPID_ELEMENT+75
#define DISPID_IHTMLDOMNODE_FIRSTCHILD         DISPID_ELEMENT+76
#define DISPID_IHTMLDOMNODE_LASTCHILD          DISPID_ELEMENT+77
#define DISPID_IHTMLDOMNODE_PREVIOUSSIBLING    DISPID_ELEMENT+78
#define DISPID_IHTMLDOMNODE_NEXTSIBLING        DISPID_ELEMENT+79

/* IHTMLDOMNode2 */
#define DISPID_IHTMLDOMNODE2_OWNERDOCUMENT     DISPID_ELEMENT+113

/* IHTMLRenderStyle */
#define DISPID_IHTMLRENDERSTYLE_TEXTLINETHROUGHSTYLE  DISPID_A_TEXTLINETHROUGHSTYLE
#define DISPID_IHTMLRENDERSTYLE_TEXTUNDERLINESTYLE    DISPID_A_TEXTUNDERLINESTYLE
#define DISPID_IHTMLRENDERSTYLE_TEXTEFFECT            DISPID_A_TEXTEFFECT
#define DISPID_IHTMLRENDERSTYLE_TEXTCOLOR             DISPID_A_TEXTCOLOR
#define DISPID_IHTMLRENDERSTYLE_TEXTBACKGROUNDCOLOR   DISPID_A_TEXTBACKGROUNDCOLOR
#define DISPID_IHTMLRENDERSTYLE_TEXTDECORATIONCOLOR   DISPID_A_TEXTDECORATIONCOLOR
#define DISPID_IHTMLRENDERSTYLE_RENDERINGPRIORITY     DISPID_A_RENDERINGPRIORITY
#define DISPID_IHTMLRENDERSTYLE_DEFAULTTEXTSELECTION  DISPID_A_DEFAULTTEXTSELECTION
#define DISPID_IHTMLRENDERSTYLE_TEXTDECORATION        DISPID_A_STYLETEXTDECORATION

/* IHTMLDOMImplementation */
#define DISPID_IHTMLDOMIMPLEMENTATION_HASFEATURE  DISPID_DOMIMPLEMENTATION

/* IHTMLDOMAttribute */
#define DISPID_IHTMLDOMATTRIBUTE_NODENAME   DISPID_DOMATTRIBUTE
#define DISPID_IHTMLDOMATTRIBUTE_NODEVALUE  DISPID_DOMATTRIBUTE+2
#define DISPID_IHTMLDOMATTRIBUTE_SPECIFIED  DISPID_DOMATTRIBUTE+1

/* IHTMLBodyElement */
#define DISPID_IHTMLBODYELEMENT_BACKGROUND        DISPID_A_BACKGROUNDIMAGE
#define DISPID_IHTMLBODYELEMENT_BGPROPERTIES      DISPID_A_BACKGROUNDATTACHMENT
#define DISPID_IHTMLBODYELEMENT_LEFTMARGIN        DISPID_A_MARGINLEFT
#define DISPID_IHTMLBODYELEMENT_TOPMARGIN         DISPID_A_MARGINTOP
#define DISPID_IHTMLBODYELEMENT_RIGHTMARGIN       DISPID_A_MARGINRIGHT
#define DISPID_IHTMLBODYELEMENT_BOTTOMMARGIN      DISPID_A_MARGINBOTTOM
#define DISPID_IHTMLBODYELEMENT_NOWRAP            DISPID_A_NOWRAP
#define DISPID_IHTMLBODYELEMENT_BGCOLOR           DISPID_BACKCOLOR
#define DISPID_IHTMLBODYELEMENT_TEXT              DISPID_A_COLOR
#define DISPID_IHTMLBODYELEMENT_LINK              DISPID_BODY+10
#define DISPID_IHTMLBODYELEMENT_VLINK             DISPID_BODY+12
#define DISPID_IHTMLBODYELEMENT_ALINK             DISPID_BODY+11
#define DISPID_IHTMLBODYELEMENT_ONLOAD            DISPID_EVPROP_ONLOAD
#define DISPID_IHTMLBODYELEMENT_ONUNLOAD          DISPID_EVPROP_ONUNLOAD
#define DISPID_IHTMLBODYELEMENT_SCROLL            DISPID_A_SCROLL
#define DISPID_IHTMLBODYELEMENT_ONSELECT          DISPID_EVPROP_ONSELECT
#define DISPID_IHTMLBODYELEMENT_ONBEFOREUNLOAD    DISPID_EVPROP_ONBEFOREUNLOAD
#define DISPID_IHTMLBODYELEMENT_CREATETEXTRANGE   DISPID_BODY+13

/* IHTMLBodyElement2 */
#define DISPID_IHTMLBODYELEMENT2_ONBEFOREPRINT   DISPID_EVPROP_ONBEFOREPRINT
#define DISPID_IHTMLBODYELEMENT2_ONAFTERPRINT    DISPID_EVPROP_ONAFTERPRINT

/* IHTMLTxtRange */
#define DISPID_IHTMLTXTRANGE_HTMLTEXT                DISPID_RANGE+3
#define DISPID_IHTMLTXTRANGE_TEXT                    DISPID_RANGE+4
#define DISPID_IHTMLTXTRANGE_PARENTELEMENT           DISPID_RANGE+6
#define DISPID_IHTMLTXTRANGE_DUPLICATE               DISPID_RANGE+8
#define DISPID_IHTMLTXTRANGE_INRANGE                 DISPID_RANGE+10
#define DISPID_IHTMLTXTRANGE_ISEQUAL                 DISPID_RANGE+11
#define DISPID_IHTMLTXTRANGE_SCROLLINTOVIEW          DISPID_RANGE+12
#define DISPID_IHTMLTXTRANGE_COLLAPSE                DISPID_RANGE+13
#define DISPID_IHTMLTXTRANGE_EXPAND                  DISPID_RANGE+14
#define DISPID_IHTMLTXTRANGE_MOVE                    DISPID_RANGE+15
#define DISPID_IHTMLTXTRANGE_MOVESTART               DISPID_RANGE+16
#define DISPID_IHTMLTXTRANGE_MOVEEND                 DISPID_RANGE+17
#define DISPID_IHTMLTXTRANGE_SELECT                  DISPID_RANGE+24
#define DISPID_IHTMLTXTRANGE_PASTEHTML               DISPID_RANGE+26
#define DISPID_IHTMLTXTRANGE_MOVETOELEMENTTEXT       DISPID_RANGE+1
#define DISPID_IHTMLTXTRANGE_SETENDPOINT             DISPID_RANGE+25
#define DISPID_IHTMLTXTRANGE_COMPAREENDPOINTS        DISPID_RANGE+18
#define DISPID_IHTMLTXTRANGE_FINDTEXT                DISPID_RANGE+19
#define DISPID_IHTMLTXTRANGE_MOVETOPOINT             DISPID_RANGE+20
#define DISPID_IHTMLTXTRANGE_GETBOOKMARK             DISPID_RANGE+21
#define DISPID_IHTMLTXTRANGE_MOVETOBOOKMARK          DISPID_RANGE+9
#define DISPID_IHTMLTXTRANGE_QUERYCOMMANDSUPPORTED   DISPID_RANGE+27
#define DISPID_IHTMLTXTRANGE_QUERYCOMMANDENABLED     DISPID_RANGE+28
#define DISPID_IHTMLTXTRANGE_QUERYCOMMANDSTATE       DISPID_RANGE+29
#define DISPID_IHTMLTXTRANGE_QUERYCOMMANDINDETERM    DISPID_RANGE+30
#define DISPID_IHTMLTXTRANGE_QUERYCOMMANDTEXT        DISPID_RANGE+31
#define DISPID_IHTMLTXTRANGE_QUERYCOMMANDVALUE       DISPID_RANGE+32
#define DISPID_IHTMLTXTRANGE_EXECCOMMAND             DISPID_RANGE+33
#define DISPID_IHTMLTXTRANGE_EXECCOMMANDSHOWHELP     DISPID_RANGE+34

/* IHTMLTextAreaElement */
#define DISPID_IHTMLTEXTAREAELEMENT_TYPE             DISPID_INPUT
#define DISPID_IHTMLTEXTAREAELEMENT_VALUE            DISPID_A_VALUE
#define DISPID_IHTMLTEXTAREAELEMENT_NAME             STDPROPID_XOBJ_NAME
#define DISPID_IHTMLTEXTAREAELEMENT_STATUS           DISPID_INPUT+1
#define DISPID_IHTMLTEXTAREAELEMENT_DISABLED         STDPROPID_XOBJ_DISABLED
#define DISPID_IHTMLTEXTAREAELEMENT_FORM             DISPID_SITE+4
#define DISPID_IHTMLTEXTAREAELEMENT_DEFAULTVALUE     DISPID_DEFAULTVALUE
#define DISPID_IHTMLTEXTAREAELEMENT_SELECT           DISPID_RICHTEXT+5
#define DISPID_IHTMLTEXTAREAELEMENT_ONCHANGE         DISPID_EVPROP_ONCHANGE
#define DISPID_IHTMLTEXTAREAELEMENT_ONSELECT         DISPID_EVPROP_ONSELECT
#define DISPID_IHTMLTEXTAREAELEMENT_READONLY         DISPID_RICHTEXT+4
#define DISPID_IHTMLTEXTAREAELEMENT_ROWS             DISPID_RICHTEXT+1
#define DISPID_IHTMLTEXTAREAELEMENT_COLS             DISPID_RICHTEXT+2
#define DISPID_IHTMLTEXTAREAELEMENT_WRAP             DISPID_RICHTEXT+3
#define DISPID_IHTMLTEXTAREAELEMENT_CREATETEXTRANGE  DISPID_RICHTEXT+6

/* IHTMLInputElement */
#define DISPID_IHTMLINPUTELEMENT_TYPE             DISPID_INPUT
#define DISPID_IHTMLINPUTELEMENT_VALUE            DISPID_A_VALUE
#define DISPID_IHTMLINPUTELEMENT_NAME             STDPROPID_XOBJ_NAME
#define DISPID_IHTMLINPUTELEMENT_STATUS           DISPID_INPUT+1
#define DISPID_IHTMLINPUTELEMENT_DISABLED         STDPROPID_XOBJ_DISABLED
#define DISPID_IHTMLINPUTELEMENT_FORM             DISPID_SITE+4
#define DISPID_IHTMLINPUTELEMENT_SIZE             DISPID_INPUT+2
#define DISPID_IHTMLINPUTELEMENT_MAXLENGTH        DISPID_INPUT+3
#define DISPID_IHTMLINPUTELEMENT_SELECT           DISPID_INPUT+4
#define DISPID_IHTMLINPUTELEMENT_ONCHANGE         DISPID_EVPROP_ONCHANGE
#define DISPID_IHTMLINPUTELEMENT_ONSELECT         DISPID_EVPROP_ONSELECT
#define DISPID_IHTMLINPUTELEMENT_DEFAULTVALUE     DISPID_DEFAULTVALUE
#define DISPID_IHTMLINPUTELEMENT_READONLY         DISPID_INPUT+5
#define DISPID_IHTMLINPUTELEMENT_CREATETEXTRANGE  DISPID_INPUT+6
#define DISPID_IHTMLINPUTELEMENT_INDETERMINATE    DISPID_INPUT+7
#define DISPID_IHTMLINPUTELEMENT_DEFAULTCHECKED   DISPID_INPUT+8
#define DISPID_IHTMLINPUTELEMENT_CHECKED          DISPID_INPUT+9
#define DISPID_IHTMLINPUTELEMENT_BORDER           DISPID_INPUT+12
#define DISPID_IHTMLINPUTELEMENT_VSPACE           DISPID_INPUT+13
#define DISPID_IHTMLINPUTELEMENT_HSPACE           DISPID_INPUT+14
#define DISPID_IHTMLINPUTELEMENT_ALT              DISPID_INPUT+10
#define DISPID_IHTMLINPUTELEMENT_SRC              DISPID_INPUT+11
#define DISPID_IHTMLINPUTELEMENT_LOWSRC           DISPID_INPUT+15
#define DISPID_IHTMLINPUTELEMENT_VRML             DISPID_INPUT+16
#define DISPID_IHTMLINPUTELEMENT_DYNSRC           DISPID_INPUT+17
#define DISPID_IHTMLINPUTELEMENT_READYSTATE       DISPID_A_READYSTATE
#define DISPID_IHTMLINPUTELEMENT_COMPLETE         DISPID_INPUT+18
#define DISPID_IHTMLINPUTELEMENT_LOOP             DISPID_INPUT+19
#define DISPID_IHTMLINPUTELEMENT_ALIGN            STDPROPID_XOBJ_CONTROLALIGN
#define DISPID_IHTMLINPUTELEMENT_ONLOAD           DISPID_EVPROP_ONLOAD
#define DISPID_IHTMLINPUTELEMENT_ONERROR          DISPID_EVPROP_ONERROR
#define DISPID_IHTMLINPUTELEMENT_ONABORT          DISPID_EVPROP_ONABORT
#define DISPID_IHTMLINPUTELEMENT_WIDTH            STDPROPID_XOBJ_WIDTH
#define DISPID_IHTMLINPUTELEMENT_HEIGHT           STDPROPID_XOBJ_HEIGHT
#define DISPID_IHTMLINPUTELEMENT_START            DISPID_INPUT+20

/* IHTMLSelectElement */
#define DISPID_IHTMLSELECTELEMENT_SIZE           DISPID_SELECT+2
#define DISPID_IHTMLSELECTELEMENT_MULTIPLE       DISPID_SELECT+3
#define DISPID_IHTMLSELECTELEMENT_NAME           STDPROPID_XOBJ_NAME
#define DISPID_IHTMLSELECTELEMENT_OPTIONS        DISPID_SELECT+5
#define DISPID_IHTMLSELECTELEMENT_ONCHANGE       DISPID_EVPROP_ONCHANGE
#define DISPID_IHTMLSELECTELEMENT_SELECTEDINDEX  DISPID_SELECT+10
#define DISPID_IHTMLSELECTELEMENT_TYPE           DISPID_SELECT+12
#define DISPID_IHTMLSELECTELEMENT_VALUE          DISPID_SELECT+11
#define DISPID_IHTMLSELECTELEMENT_DISABLED       STDPROPID_XOBJ_DISABLED
#define DISPID_IHTMLSELECTELEMENT_FORM           DISPID_SITE+4
#define DISPID_IHTMLSELECTELEMENT_ADD            DISPID_COLLECTION+3
#define DISPID_IHTMLSELECTELEMENT_REMOVE         DISPID_COLLECTION+4
#define DISPID_IHTMLSELECTELEMENT_LENGTH         DISPID_COLLECTION
#define DISPID_IHTMLSELECTELEMENT__NEWENUM       DISPID_NEWENUM
#define DISPID_IHTMLSELECTELEMENT_ITEM           DISPID_VALUE
#define DISPID_IHTMLSELECTELEMENT_TAGS           DISPID_COLLECTION+2

/* IHTMLRect */
#define DISPID_IHTMLRECT_LEFT    DISPID_OMRECT+1
#define DISPID_IHTMLRECT_TOP     DISPID_OMRECT+2
#define DISPID_IHTMLRECT_RIGHT   DISPID_OMRECT+3
#define DISPID_IHTMLRECT_BOTTOM  DISPID_OMRECT+4

/* IHTMLRectCollection */
#define DISPID_IHTMLRECTCOLLECTION_LENGTH    DISPID_COLLECTION
#define DISPID_IHTMLRECTCOLLECTION__NEWENUM  DISPID_NEWENUM
#define DISPID_IHTMLRECTCOLLECTION_ITEM      DISPID_VALUE

/* IHTMLCurrentStyle */
#define DISPID_IHTMLCURRENTSTYLE_POSITION              DISPID_A_POSITION
#define DISPID_IHTMLCURRENTSTYLE_STYLEFLOAT            DISPID_A_FLOAT
#define DISPID_IHTMLCURRENTSTYLE_COLOR                 DISPID_A_COLOR
#define DISPID_IHTMLCURRENTSTYLE_BACKGROUNDCOLOR       DISPID_BACKCOLOR
#define DISPID_IHTMLCURRENTSTYLE_FONTFAMILY            DISPID_A_FONTFACE
#define DISPID_IHTMLCURRENTSTYLE_FONTSTYLE             DISPID_A_FONTSTYLE
#define DISPID_IHTMLCURRENTSTYLE_FONTVARIANT           DISPID_A_FONTVARIANT
#define DISPID_IHTMLCURRENTSTYLE_FONTWEIGHT            DISPID_A_FONTWEIGHT
#define DISPID_IHTMLCURRENTSTYLE_FONTSIZE              DISPID_A_FONTSIZE
#define DISPID_IHTMLCURRENTSTYLE_BACKGROUNDIMAGE       DISPID_A_BACKGROUNDIMAGE
#define DISPID_IHTMLCURRENTSTYLE_BACKGROUNDPOSITIONX   DISPID_A_BACKGROUNDPOSX
#define DISPID_IHTMLCURRENTSTYLE_BACKGROUNDPOSITIONY   DISPID_A_BACKGROUNDPOSY
#define DISPID_IHTMLCURRENTSTYLE_BACKGROUNDREPEAT      DISPID_A_BACKGROUNDREPEAT
#define DISPID_IHTMLCURRENTSTYLE_BORDERLEFTCOLOR       DISPID_A_BORDERLEFTCOLOR
#define DISPID_IHTMLCURRENTSTYLE_BORDERTOPCOLOR        DISPID_A_BORDERTOPCOLOR
#define DISPID_IHTMLCURRENTSTYLE_BORDERRIGHTCOLOR      DISPID_A_BORDERRIGHTCOLOR
#define DISPID_IHTMLCURRENTSTYLE_BORDERBOTTOMCOLOR     DISPID_A_BORDERBOTTOMCOLOR
#define DISPID_IHTMLCURRENTSTYLE_BORDERTOPSTYLE        DISPID_A_BORDERTOPSTYLE
#define DISPID_IHTMLCURRENTSTYLE_BORDERRIGHTSTYLE      DISPID_A_BORDERRIGHTSTYLE
#define DISPID_IHTMLCURRENTSTYLE_BORDERBOTTOMSTYLE     DISPID_A_BORDERBOTTOMSTYLE
#define DISPID_IHTMLCURRENTSTYLE_BORDERLEFTSTYLE       DISPID_A_BORDERLEFTSTYLE
#define DISPID_IHTMLCURRENTSTYLE_BORDERTOPWIDTH        DISPID_A_BORDERTOPWIDTH
#define DISPID_IHTMLCURRENTSTYLE_BORDERRIGHTWIDTH      DISPID_A_BORDERRIGHTWIDTH
#define DISPID_IHTMLCURRENTSTYLE_BORDERBOTTOMWIDTH     DISPID_A_BORDERBOTTOMWIDTH
#define DISPID_IHTMLCURRENTSTYLE_BORDERLEFTWIDTH       DISPID_A_BORDERLEFTWIDTH
#define DISPID_IHTMLCURRENTSTYLE_LEFT                  STDPROPID_XOBJ_LEFT
#define DISPID_IHTMLCURRENTSTYLE_TOP                   STDPROPID_XOBJ_TOP
#define DISPID_IHTMLCURRENTSTYLE_WIDTH                 STDPROPID_XOBJ_WIDTH
#define DISPID_IHTMLCURRENTSTYLE_HEIGHT                STDPROPID_XOBJ_HEIGHT
#define DISPID_IHTMLCURRENTSTYLE_PADDINGLEFT           DISPID_A_PADDINGLEFT
#define DISPID_IHTMLCURRENTSTYLE_PADDINGTOP            DISPID_A_PADDINGTOP
#define DISPID_IHTMLCURRENTSTYLE_PADDINGRIGHT          DISPID_A_PADDINGRIGHT
#define DISPID_IHTMLCURRENTSTYLE_PADDINGBOTTOM         DISPID_A_PADDINGBOTTOM
#define DISPID_IHTMLCURRENTSTYLE_TEXTALIGN             STDPROPID_XOBJ_BLOCKALIGN
#define DISPID_IHTMLCURRENTSTYLE_TEXTDECORATION        DISPID_A_TEXTDECORATION
#define DISPID_IHTMLCURRENTSTYLE_DISPLAY               DISPID_A_DISPLAY
#define DISPID_IHTMLCURRENTSTYLE_VISIBILITY            DISPID_A_VISIBILITY
#define DISPID_IHTMLCURRENTSTYLE_ZINDEX                DISPID_A_ZINDEX
#define DISPID_IHTMLCURRENTSTYLE_LETTERSPACING         DISPID_A_LETTERSPACING
#define DISPID_IHTMLCURRENTSTYLE_LINEHEIGHT            DISPID_A_LINEHEIGHT
#define DISPID_IHTMLCURRENTSTYLE_TEXTINDENT            DISPID_A_TEXTINDENT
#define DISPID_IHTMLCURRENTSTYLE_VERTICALALIGN         DISPID_A_VERTICALALIGN
#define DISPID_IHTMLCURRENTSTYLE_BACKGROUNDATTACHMENT  DISPID_A_BACKGROUNDATTACHMENT
#define DISPID_IHTMLCURRENTSTYLE_MARGINTOP             DISPID_A_MARGINTOP
#define DISPID_IHTMLCURRENTSTYLE_MARGINRIGHT           DISPID_A_MARGINRIGHT
#define DISPID_IHTMLCURRENTSTYLE_MARGINBOTTOM          DISPID_A_MARGINBOTTOM
#define DISPID_IHTMLCURRENTSTYLE_MARGINLEFT            DISPID_A_MARGINLEFT
#define DISPID_IHTMLCURRENTSTYLE_CLEAR                 DISPID_A_CLEAR
#define DISPID_IHTMLCURRENTSTYLE_LISTSTYLETYPE         DISPID_A_LISTSTYLETYPE
#define DISPID_IHTMLCURRENTSTYLE_LISTSTYLEPOSITION     DISPID_A_LISTSTYLEPOSITION
#define DISPID_IHTMLCURRENTSTYLE_LISTSTYLEIMAGE        DISPID_A_LISTSTYLEIMAGE
#define DISPID_IHTMLCURRENTSTYLE_CLIPTOP               DISPID_A_CLIPRECTTOP
#define DISPID_IHTMLCURRENTSTYLE_CLIPRIGHT             DISPID_A_CLIPRECTRIGHT
#define DISPID_IHTMLCURRENTSTYLE_CLIPBOTTOM            DISPID_A_CLIPRECTBOTTOM
#define DISPID_IHTMLCURRENTSTYLE_CLIPLEFT              DISPID_A_CLIPRECTLEFT
#define DISPID_IHTMLCURRENTSTYLE_OVERFLOW              DISPID_A_OVERFLOW
#define DISPID_IHTMLCURRENTSTYLE_PAGEBREAKBEFORE       DISPID_A_PAGEBREAKBEFORE
#define DISPID_IHTMLCURRENTSTYLE_PAGEBREAKAFTER        DISPID_A_PAGEBREAKAFTER
#define DISPID_IHTMLCURRENTSTYLE_CURSOR                DISPID_A_CURSOR
#define DISPID_IHTMLCURRENTSTYLE_TABLELAYOUT           DISPID_A_TABLELAYOUT
#define DISPID_IHTMLCURRENTSTYLE_BORDERCOLLAPSE        DISPID_A_BORDERCOLLAPSE
#define DISPID_IHTMLCURRENTSTYLE_DIRECTION             DISPID_A_DIRECTION
#define DISPID_IHTMLCURRENTSTYLE_BEHAVIOR              DISPID_A_BEHAVIOR
#define DISPID_IHTMLCURRENTSTYLE_GETATTRIBUTE          DISPID_HTMLOBJECT+2
#define DISPID_IHTMLCURRENTSTYLE_UNICODEBIDI           DISPID_A_UNICODEBIDI
#define DISPID_IHTMLCURRENTSTYLE_RIGHT                 STDPROPID_XOBJ_RIGHT
#define DISPID_IHTMLCURRENTSTYLE_BOTTOM                STDPROPID_XOBJ_BOTTOM
#define DISPID_IHTMLCURRENTSTYLE_IMEMODE               DISPID_A_IMEMODE
#define DISPID_IHTMLCURRENTSTYLE_RUBYALIGN             DISPID_A_RUBYALIGN
#define DISPID_IHTMLCURRENTSTYLE_RUBYPOSITION          DISPID_A_RUBYPOSITION
#define DISPID_IHTMLCURRENTSTYLE_RUBYOVERHANG          DISPID_A_RUBYOVERHANG
#define DISPID_IHTMLCURRENTSTYLE_TEXTAUTOSPACE         DISPID_A_TEXTAUTOSPACE
#define DISPID_IHTMLCURRENTSTYLE_LINEBREAK             DISPID_A_LINEBREAK
#define DISPID_IHTMLCURRENTSTYLE_WORDBREAK             DISPID_A_WORDBREAK
#define DISPID_IHTMLCURRENTSTYLE_TEXTJUSTIFY           DISPID_A_TEXTJUSTIFY
#define DISPID_IHTMLCURRENTSTYLE_TEXTJUSTIFYTRIM       DISPID_A_TEXTJUSTIFYTRIM
#define DISPID_IHTMLCURRENTSTYLE_TEXTKASHIDA           DISPID_A_TEXTKASHIDA
#define DISPID_IHTMLCURRENTSTYLE_BLOCKDIRECTION        DISPID_A_DIR
#define DISPID_IHTMLCURRENTSTYLE_LAYOUTGRIDCHAR        DISPID_A_LAYOUTGRIDCHAR
#define DISPID_IHTMLCURRENTSTYLE_LAYOUTGRIDLINE        DISPID_A_LAYOUTGRIDLINE
#define DISPID_IHTMLCURRENTSTYLE_LAYOUTGRIDMODE        DISPID_A_LAYOUTGRIDMODE
#define DISPID_IHTMLCURRENTSTYLE_LAYOUTGRIDTYPE        DISPID_A_LAYOUTGRIDTYPE
#define DISPID_IHTMLCURRENTSTYLE_BORDERSTYLE           DISPID_A_BORDERSTYLE
#define DISPID_IHTMLCURRENTSTYLE_BORDERCOLOR           DISPID_A_BORDERCOLOR
#define DISPID_IHTMLCURRENTSTYLE_BORDERWIDTH           DISPID_A_BORDERWIDTH
#define DISPID_IHTMLCURRENTSTYLE_PADDING               DISPID_A_PADDING
#define DISPID_IHTMLCURRENTSTYLE_MARGIN                DISPID_A_MARGIN
#define DISPID_IHTMLCURRENTSTYLE_ACCELERATOR           DISPID_A_ACCELERATOR
#define DISPID_IHTMLCURRENTSTYLE_OVERFLOWX             DISPID_A_OVERFLOWX
#define DISPID_IHTMLCURRENTSTYLE_OVERFLOWY             DISPID_A_OVERFLOWY
#define DISPID_IHTMLCURRENTSTYLE_TEXTTRANSFORM         DISPID_A_TEXTTRANSFORM

/* HTMLTextContainerEvents2 */
#define DISPID_HTMLTEXTCONTAINEREVENTS2_ONCHANGE       DISPID_EVMETH_ONCHANGE
#define DISPID_HTMLTEXTCONTAINEREVENTS2_ONSELECT       DISPID_EVMETH_ONSELECT

/* HTMLTextContainerEvents */
#define DISPID_HTMLTEXTCONTAINEREVENTS_ONCHANGE        DISPID_EVMETH_ONCHANGE
#define DISPID_HTMLTEXTCONTAINEREVENTS_ONSELECT        DISPID_EVMETH_ONSELECT

/* IHTMLTextContainer */
#define DISPID_IHTMLTEXTCONTAINER_CREATECONTROLRANGE  DISPID_TEXTSITE+1
#define DISPID_IHTMLTEXTCONTAINER_SCROLLHEIGHT        DISPID_TEXTSITE+2
#define DISPID_IHTMLTEXTCONTAINER_SCROLLWIDTH         DISPID_TEXTSITE+3
#define DISPID_IHTMLTEXTCONTAINER_SCROLLTOP           DISPID_TEXTSITE+4
#define DISPID_IHTMLTEXTCONTAINER_SCROLLLEFT          DISPID_TEXTSITE+5
#define DISPID_IHTMLTEXTCONTAINER_ONSCROLL            DISPID_EVPROP_ONSCROLL

/* IHTMLFrameBase2 */
#define DISPID_IHTMLFRAMEBASE2_CONTENTWINDOW       DISPID_FRAMESITE+9
#define DISPID_IHTMLFRAMEBASE2_ONLOAD              DISPID_EVPROP_ONLOAD
#define DISPID_IHTMLFRAMEBASE2_ONREADYSTATECHANGE  DISPID_EVPROP_ONREADYSTATECHANGE
#define DISPID_IHTMLFRAMEBASE2_READYSTATE          DISPID_A_READYSTATE
#define DISPID_IHTMLFRAMEBASE2_ALLOWTRANSPARENCY   DISPID_A_ALLOWTRANSPARENCY

#endif /* __MSHTMDID_H__ */
